@@ -42,10 +42,12 @@ import org.apache.commons.codec.binary.StringUtils;
  * The {@link MessageDigestAlgorithms} class provides constants for standard
  * digest algorithms that can be used with the {@link #getDigest(String)} method
  * and other methods that require the Digest algorithm name.
+ * </p>
  * <p>
- * Note: the class has short-hand methods for all the algorithms present as standard in Java 6.
+ * Note: the class has shorthand methods for all the algorithms present as standard in Java 6.
  * This approach requires lots of methods for each algorithm, and quickly becomes unwieldy.
  * The following code works with all algorithms:
+ * </p>
  * <pre>
  * import static org.apache.commons.codec.digest.MessageDigestAlgorithms.SHA_224;
  * ...
@@ -58,6 +60,8 @@ public class DigestUtils {
 
     private static final int STREAM_BUFFER_LENGTH = 1024;
 
+    private final MessageDigest messageDigest;
+
     /**
      * Reads through a byte array and returns the digest for the data. Provided for symmetry with other methods.
      *
@@ -258,7 +262,7 @@ public class DigestUtils {
      * @return An SHA3-224 digest instance.
      * @throws IllegalArgumentException
      *             when a {@link NoSuchAlgorithmException} is caught, which should not happen on
-     *             Oracle Java 9 andgreater.
+     *             Oracle Java 9 and greater.
      * @see MessageDigestAlgorithms#SHA3_224
      * @since 1.12
      */
@@ -1496,6 +1500,7 @@ public class DigestUtils {
      * @throws IOException On error reading from the stream
      * @since 1.14
      */
+    @SuppressWarnings("resource") // Closing RandomAccessFile closes the channel.
     public static MessageDigest updateDigest(final MessageDigest digest, final RandomAccessFile data)
             throws IOException {
         return updateDigest(digest, data.getChannel());
@@ -1522,8 +1527,6 @@ public class DigestUtils {
         return messageDigest;
     }
 
-    private final MessageDigest messageDigest;
-
    /**
     * Preserves binary compatibility only.
     * As for previous versions does not provide useful behavior
