@@ -17,16 +17,16 @@
 
 package org.apache.commons.codec.binary;
 
-import org.junit.Test;
+import static org.junit.jupiter.api.Assertions.assertArrayEquals;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertThrows;
 
 import java.io.ByteArrayInputStream;
-import java.io.InputStream;
 import java.io.IOException;
+import java.io.InputStream;
 
-import static org.junit.Assert.assertArrayEquals;
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.fail;
+import org.junit.jupiter.api.Test;
 
 /**
  * @since 1.15
@@ -66,8 +66,8 @@ public class Base16InputStreamTest {
      */
     @Test
     public void testBase16EmptyInputStream() throws IOException {
-        final byte[] emptyEncoded = new byte[0];
-        final byte[] emptyDecoded = new byte[0];
+        final byte[] emptyEncoded = {};
+        final byte[] emptyDecoded = {};
         testByteByByte(emptyEncoded, emptyDecoded);
         testByChunk(emptyEncoded, emptyDecoded);
     }
@@ -95,7 +95,7 @@ public class Base16InputStreamTest {
         decoded = BaseNTestData.DECODED;
         testByChunk(encoded, decoded);
 
-        // test random data of sizes 0 thru 150
+        // test random data of sizes 0 through 150
         final BaseNCodec codec = new Base16(true);
         for (int i = 0; i <= 150; i++) {
             final byte[][] randomData = BaseNTestData.randomData(codec, i);
@@ -127,7 +127,7 @@ public class Base16InputStreamTest {
         decoded = BaseNTestData.DECODED;
         testByteByByte(encoded, decoded);
 
-        // test random data of sizes 0 thru 150
+        // test random data of sizes 0 through 150
         final BaseNCodec codec = new Base16(true);
         for (int i = 0; i <= 150; i++) {
             final byte[][] randomData = BaseNTestData.randomData(codec, i);
@@ -170,18 +170,18 @@ public class Base16InputStreamTest {
         try (final InputStream in = new Base16InputStream(new ByteArrayInputStream(decoded), true, lowerCase)) {
             final byte[] output = BaseNTestData.streamToBytes(in);
 
-            assertEquals("EOF", -1, in.read());
-            assertEquals("Still EOF", -1, in.read());
-            assertArrayEquals("Streaming Base16 encode", encoded, output);
+            assertEquals(-1, in.read(), "EOF");
+            assertEquals(-1, in.read(), "Still EOF");
+            assertArrayEquals(encoded, output, "Streaming Base16 encode");
         }
 
-        // Now let's try decode.
+        // Now let's try to decode.
         try (final InputStream in = new Base16InputStream(new ByteArrayInputStream(encoded), false, lowerCase)) {
             final byte[] output = BaseNTestData.streamToBytes(in);
 
-            assertEquals("EOF", -1, in.read());
-            assertEquals("Still EOF", -1, in.read());
-            assertArrayEquals("Streaming Base16 decode", decoded, output);
+            assertEquals(-1, in.read(), "EOF");
+            assertEquals(-1, in.read(), "Still EOF");
+            assertArrayEquals(decoded, output, "Streaming Base16 decode");
         }
 
         // wrap encoder with decoder
@@ -191,9 +191,9 @@ public class Base16InputStreamTest {
 
             final byte[] output = BaseNTestData.streamToBytes(inDecode);
 
-            assertEquals("EOF", -1, inDecode.read());
-            assertEquals("Still EOF", -1, inDecode.read());
-            assertArrayEquals("Streaming Base16 wrap-wrap!", decoded, output);
+            assertEquals(-1, inDecode.read(), "EOF");
+            assertEquals(-1, inDecode.read(), "Still EOF");
+            assertArrayEquals(decoded, output, "Streaming Base16 wrap-wrap!");
         }
     }
 
@@ -233,21 +233,21 @@ public class Base16InputStreamTest {
                 output[i] = (byte) in.read();
             }
 
-            assertEquals("EOF", -1, in.read());
-            assertEquals("Still EOF", -1, in.read());
-            assertArrayEquals("Streaming Base16 encode", encoded, output);
+            assertEquals(-1, in.read(), "EOF");
+            assertEquals(-1, in.read(), "Still EOF");
+            assertArrayEquals(encoded, output, "Streaming Base16 encode");
         }
 
-        // Now let's try decode.
+        // Now let's try to decode.
         try (final InputStream in = new Base16InputStream(new ByteArrayInputStream(encoded), false, lowerCase)) {
             final byte[] output = new byte[decoded.length];
             for (int i = 0; i < output.length; i++) {
                 output[i] = (byte) in.read();
             }
 
-            assertEquals("EOF", -1, in.read());
-            assertEquals("Still EOF", -1, in.read());
-            assertArrayEquals("Streaming Base16 decode", decoded, output);
+            assertEquals(-1, in.read(), "EOF");
+            assertEquals(-1, in.read(), "Still EOF");
+            assertArrayEquals(decoded, output, "Streaming Base16 decode");
         }
 
         // wrap encoder with decoder
@@ -260,9 +260,9 @@ public class Base16InputStreamTest {
                 output[i] = (byte) inDecode.read();
             }
 
-            assertEquals("EOF", -1, inDecode.read());
-            assertEquals("Still EOF", -1, inDecode.read());
-            assertArrayEquals("Streaming Base16 wrap-wrap!", decoded, output);
+            assertEquals(-1, inDecode.read(), "EOF");
+            assertEquals(-1, inDecode.read(), "Still EOF");
+            assertArrayEquals(decoded, output, "Streaming Base16 wrap-wrap!");
         }
     }
 
@@ -277,7 +277,7 @@ public class Base16InputStreamTest {
         final ByteArrayInputStream bin = new ByteArrayInputStream(decoded);
         try (final Base16InputStream in = new Base16InputStream(bin, true)) {
             // Always returns false for now.
-            assertFalse("Base16InputStream.markSupported() is false", in.markSupported());
+            assertFalse(in.markSupported(), "Base16InputStream.markSupported() is false");
         }
     }
 
@@ -294,7 +294,7 @@ public class Base16InputStreamTest {
         final ByteArrayInputStream bin = new ByteArrayInputStream(decoded);
         try (final Base16InputStream in = new Base16InputStream(bin, true)) {
             bytesRead = in.read(buf, 0, 0);
-            assertEquals("Base16InputStream.read(buf, 0, 0) returns 0", 0, bytesRead);
+            assertEquals(0, bytesRead, "Base16InputStream.read(buf, 0, 0) returns 0");
         }
     }
 
@@ -308,10 +308,8 @@ public class Base16InputStreamTest {
         final byte[] decoded = StringUtils.getBytesUtf8(STRING_FIXTURE);
         final ByteArrayInputStream bin = new ByteArrayInputStream(decoded);
         try (final Base16InputStream in = new Base16InputStream(bin, true)) {
-            in.read(null, 0, 0);
-            fail("Base16InputStream.read(null, 0, 0) to throw a NullPointerException");
-        } catch (final NullPointerException e) {
-            // Expected
+            assertThrows(NullPointerException.class, () -> in.read(null, 0, 0),
+                "Base16InputStream.read(null, 0, 0)");
         }
     }
 
@@ -326,34 +324,10 @@ public class Base16InputStreamTest {
         final byte[] buf = new byte[1024];
         final ByteArrayInputStream bin = new ByteArrayInputStream(decoded);
         try (final Base16InputStream in = new Base16InputStream(bin, true)) {
-
-            try {
-                in.read(buf, -1, 0);
-                fail("Expected Base16InputStream.read(buf, -1, 0) to throw IndexOutOfBoundsException");
-            } catch (final IndexOutOfBoundsException e) {
-                // Expected
-            }
-
-            try {
-                in.read(buf, 0, -1);
-                fail("Expected Base16InputStream.read(buf, 0, -1) to throw IndexOutOfBoundsException");
-            } catch (final IndexOutOfBoundsException e) {
-                // Expected
-            }
-
-            try {
-                in.read(buf, buf.length + 1, 0);
-                fail("Base16InputStream.read(buf, buf.length + 1, 0) throws IndexOutOfBoundsException");
-            } catch (final IndexOutOfBoundsException e) {
-                // Expected
-            }
-
-            try {
-                in.read(buf, buf.length - 1, 2);
-                fail("Base16InputStream.read(buf, buf.length - 1, 2) throws IndexOutOfBoundsException");
-            } catch (final IndexOutOfBoundsException e) {
-                // Expected
-            }
+            assertThrows(IndexOutOfBoundsException.class, () -> in.read(buf, -1, 0), "Base16InputStream.read(buf, -1, 0)");
+            assertThrows(IndexOutOfBoundsException.class, () -> in.read(buf, 0, -1), "Base16InputStream.read(buf, 0, -1)");
+            assertThrows(IndexOutOfBoundsException.class, () -> in.read(buf, buf.length + 1, 0), "Base16InputStream.read(buf, buf.length + 1, 0)");
+            assertThrows(IndexOutOfBoundsException.class, () -> in.read(buf, buf.length - 1, 2), "Base16InputStream.read(buf, buf.length - 1, 2)");
         }
     }
 
@@ -430,11 +404,11 @@ public class Base16InputStreamTest {
      *
      * @throws IOException for some failure scenarios.
      */
-    @Test(expected=IllegalArgumentException.class)
+    @Test
     public void testSkipWrongArgument() throws IOException {
         final InputStream ins = new ByteArrayInputStream(StringUtils.getBytesIso8859_1(ENCODED_B16));
         try (final Base16InputStream b16Stream = new Base16InputStream(ins)) {
-            b16Stream.skip(-10);
+            assertThrows(IllegalArgumentException.class, () -> b16Stream.skip(-10));
         }
     }
 }
