@@ -17,23 +17,22 @@
 
 package org.apache.commons.codec.binary;
 
+import static org.junit.jupiter.api.Assertions.assertArrayEquals;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertNull;
+import static org.junit.jupiter.api.Assertions.assertThrows;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+
+import java.nio.charset.Charset;
+import java.nio.charset.StandardCharsets;
+import java.util.Random;
+
 import org.apache.commons.codec.CodecPolicy;
 import org.apache.commons.codec.DecoderException;
 import org.apache.commons.codec.EncoderException;
 import org.apache.commons.lang3.ArrayUtils;
-import org.junit.Test;
-
-import java.nio.charset.Charset;
-import java.nio.charset.StandardCharsets;
-import java.util.Arrays;
-import java.util.Random;
-
-import static org.junit.Assert.assertArrayEquals;
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertNull;
-import static org.junit.Assert.assertTrue;
-import static org.junit.Assert.fail;
+import org.junit.jupiter.api.Test;
 
 /**
  * Test cases for Base16 class.
@@ -61,11 +60,11 @@ public class Base16Test {
         final String content = "Hello World";
         final byte[] encodedBytes = new Base16().encode(StringUtils.getBytesUtf8(content));
         final String encodedContent = StringUtils.newStringUtf8(encodedBytes);
-        assertEquals("encoding hello world", "48656C6C6F20576F726C64", encodedContent);
+        assertEquals("48656C6C6F20576F726C64", encodedContent, "encoding hello world");
 
         final byte[] decodedBytes = new Base16().decode(encodedBytes);
         final String decodedContent = StringUtils.newStringUtf8(decodedBytes);
-        assertEquals("decoding hello world", content, decodedContent);
+        assertEquals(content, decodedContent, "decoding hello world");
     }
 
     @Test
@@ -85,24 +84,24 @@ public class Base16Test {
 
     private void testBase16InBuffer(final int startPasSize, final int endPadSize) {
         final String content = "Hello World";
-        String encodedContent;
+        final String encodedContent;
         final byte[] bytesUtf8 = StringUtils.getBytesUtf8(content);
         byte[] buffer = ArrayUtils.addAll(bytesUtf8, new byte[endPadSize]);
         buffer = ArrayUtils.addAll(new byte[startPasSize], buffer);
         final byte[] encodedBytes = new Base16().encode(buffer, startPasSize, bytesUtf8.length);
         encodedContent = StringUtils.newStringUtf8(encodedBytes);
-        assertEquals("encoding hello world", "48656C6C6F20576F726C64", encodedContent);
+        assertEquals("48656C6C6F20576F726C64", encodedContent, "encoding hello world");
     }
 
     /**
      * isBase16 throws RuntimeException on some
      * non-Base16 bytes
      */
-    @Test(expected=RuntimeException.class)
+    @Test
     public void testCodec68() {
-        final byte[] x = new byte[] { 'n', 'H', '=', '=', (byte) 0x9c };
+        final byte[] x = { 'n', 'H', '=', '=', (byte) 0x9c };
         final Base16 b16 = new Base16();
-        b16.decode(x);
+        assertThrows(RuntimeException.class, () -> b16.decode(x));
     }
 
     @Test
@@ -120,7 +119,7 @@ public class Base16Test {
         final byte[] encoded = base16.encode(BaseNTestData.DECODED);
         final String expectedResult = Base16TestData.ENCODED_UTF8_LOWERCASE;
         final String result = StringUtils.newStringUtf8(encoded);
-        assertEquals("new Base16(true)", expectedResult, result);
+        assertEquals(expectedResult, result, "new Base16(true)");
     }
 
     @Test
@@ -129,7 +128,7 @@ public class Base16Test {
         final byte[] encoded = base16.encode(BaseNTestData.DECODED);
         final String expectedResult = Base16TestData.ENCODED_UTF8_UPPERCASE;
         final String result = StringUtils.newStringUtf8(encoded);
-        assertEquals("new base16(false, CodecPolicy.STRICT)", result, expectedResult);
+        assertEquals(result, expectedResult, "new base16(false, CodecPolicy.STRICT)");
     }
 
     /**
@@ -137,18 +136,18 @@ public class Base16Test {
      */
     @Test
     public void testEmptyBase16() {
-        byte[] empty = new byte[0];
+        byte[] empty = {};
         byte[] result = new Base16().encode(empty);
-        assertEquals("empty Base16 encode", 0, result.length);
-        assertEquals("empty Base16 encode", null, new Base16().encode(null));
+        assertEquals(0, result.length, "empty Base16 encode");
+        assertNull(new Base16().encode(null), "empty Base16 encode");
         result = new Base16().encode(empty, 0, 1);
-        assertEquals("empty Base16 encode with offset", 0, result.length);
-        assertEquals("empty Base16 encode with offset", null, new Base16().encode(null));
+        assertEquals(0, result.length, "empty Base16 encode with offset");
+        assertNull(new Base16().encode(null), "empty Base16 encode with offset");
 
         empty = new byte[0];
         result = new Base16().decode(empty);
-        assertEquals("empty Base16 decode", 0, result.length);
-        assertEquals("empty Base16 encode", null, new Base16().decode((byte[]) null));
+        assertEquals(0, result.length, "empty Base16 decode");
+        assertNull(new Base16().decode((byte[]) null), "empty Base16 encode");
     }
 
     // encode/decode a large random array
@@ -172,7 +171,7 @@ public class Base16Test {
             this.getRandom().nextBytes(data);
             final byte[] enc = new Base16().encode(data);
             final byte[] data2 = new Base16().decode(enc);
-            assertArrayEquals(toString(data) + " equals " + toString(data2), data, data2);
+            assertArrayEquals(data, data2, toString(data) + " equals " + toString(data2));
         }
     }
 
@@ -212,27 +211,14 @@ public class Base16Test {
 
         final byte[] encoded = new byte[1];
         for (final byte invalidEncodedChar : invalidEncodedChars) {
-            try {
-                encoded[0] = invalidEncodedChar;
-                new Base16().decode(encoded);
-                fail("IllegalArgumentException should have been thrown when trying to decode invalid Base16 char: " + (char)invalidEncodedChar);
-            } catch (final Exception e) {
-                assertTrue(e instanceof IllegalArgumentException);
-            }
+            encoded[0] = invalidEncodedChar;
+            assertThrows(IllegalArgumentException.class, () -> new Base16().decode(encoded), "Invalid Base16 char: " + (char) invalidEncodedChar);
         }
     }
 
     @Test
     public void testObjectDecodeWithInvalidParameter() {
-        final Base16 b16 = new Base16();
-
-        try {
-            b16.decode(Integer.valueOf(5));
-            fail("decode(Object) didn't throw an exception when passed an Integer object");
-        } catch (final DecoderException e) {
-            // ignored
-        }
-
+        assertThrows(DecoderException.class, () -> new Base16().decode(Integer.valueOf(5)));
     }
 
     @Test
@@ -245,18 +231,12 @@ public class Base16Test {
         final byte[] baDecoded = (byte[]) oDecoded;
         final String dest = new String(baDecoded);
 
-        assertEquals("dest string does not equal original", original, dest);
+        assertEquals(original, dest, "dest string does not equal original");
     }
 
     @Test
     public void testObjectEncodeWithInvalidParameter() {
-        final Base16 b16 = new Base16();
-        try {
-            b16.encode("Yadayadayada");
-            fail("encode(Object) didn't throw an exception when passed a String object");
-        } catch (final EncoderException e) {
-            // Expected
-        }
+        assertThrows(EncoderException.class, () -> new Base16().encode("Yadayadayada"));
     }
 
     @Test
@@ -268,13 +248,13 @@ public class Base16Test {
         final byte[] bArray = new Base16().decode((byte[]) oEncoded);
         final String dest = new String(bArray);
 
-        assertEquals("dest string does not equal original", original, dest);
+        assertEquals(original, dest, "dest string does not equal original");
     }
 
     @Test
     public void testObjectEncode() {
         final Base16 b16 = new Base16();
-        assertEquals("48656C6C6F20576F726C64", new String(b16.encode("Hello World".getBytes(CHARSET_UTF8))));
+        assertEquals(new String(b16.encode("Hello World".getBytes(CHARSET_UTF8))), "48656C6C6F20576F726C64");
     }
 
     @Test
@@ -412,7 +392,7 @@ public class Base16Test {
         assertEquals("68", new String(new Base16().encode(new byte[] { (byte) 104 })));
         for (int i = -128; i <= 127; i++) {
             final byte test[] = { (byte) i };
-            assertTrue(Arrays.equals(test, new Base16().decode(new Base16().encode(test))));
+            assertArrayEquals(test, new Base16().decode(new Base16().encode(test)));
         }
     }
 
@@ -437,18 +417,18 @@ public class Base16Test {
     }
 
     @Test
-    public void testByteToStringVariations() throws DecoderException {
+    public void testByteToStringVariations() {
         final Base16 base16 = new Base16();
         final byte[] b1 = StringUtils.getBytesUtf8("Hello World");
-        final byte[] b2 = new byte[0];
+        final byte[] b2 = {};
         final byte[] b3 = null;
 
-        assertEquals("byteToString Hello World", "48656C6C6F20576F726C64", base16.encodeToString(b1));
-        assertEquals("byteToString static Hello World", "48656C6C6F20576F726C64", StringUtils.newStringUtf8(new Base16().encode(b1)));
-        assertEquals("byteToString \"\"", "", base16.encodeToString(b2));
-        assertEquals("byteToString static \"\"", "", StringUtils.newStringUtf8(new Base16().encode(b2)));
-        assertEquals("byteToString null", null, base16.encodeToString(b3));
-        assertEquals("byteToString static null", null, StringUtils.newStringUtf8(new Base16().encode(b3)));
+        assertEquals("48656C6C6F20576F726C64", base16.encodeToString(b1), "byteToString Hello World");
+        assertEquals("48656C6C6F20576F726C64", StringUtils.newStringUtf8(new Base16().encode(b1)), "byteToString static Hello World");
+        assertEquals("", base16.encodeToString(b2), "byteToString \"\"");
+        assertEquals("", StringUtils.newStringUtf8(new Base16().encode(b2)), "byteToString static \"\"");
+        assertNull(base16.encodeToString(b3), "byteToString null");
+        assertNull(StringUtils.newStringUtf8(new Base16().encode(b3)), "byteToString static null");
     }
 
     @Test
@@ -458,15 +438,13 @@ public class Base16Test {
         final String s2 = "";
         final String s3 = null;
 
-        assertEquals("StringToByte Hello World", "Hello World", StringUtils.newStringUtf8(base16.decode(s1)));
-        assertEquals("StringToByte Hello World", "Hello World",
-                StringUtils.newStringUtf8((byte[]) new Base16().decode((Object) s1)));
-        assertEquals("StringToByte static Hello World", "Hello World",
-                StringUtils.newStringUtf8(new Base16().decode(s1)));
-        assertEquals("StringToByte \"\"", "", StringUtils.newStringUtf8(new Base16().decode(s2)));
-        assertEquals("StringToByte static \"\"", "", StringUtils.newStringUtf8(new Base16().decode(s2)));
-        assertEquals("StringToByte null", null, StringUtils.newStringUtf8(new Base16().decode(s3)));
-        assertEquals("StringToByte static null", null, StringUtils.newStringUtf8(new Base16().decode(s3)));
+        assertEquals("Hello World", StringUtils.newStringUtf8(base16.decode(s1)), "StringToByte Hello World");
+        assertEquals("Hello World", StringUtils.newStringUtf8((byte[]) new Base16().decode((Object) s1)), "StringToByte Hello World");
+        assertEquals("Hello World", StringUtils.newStringUtf8(new Base16().decode(s1)), "StringToByte static Hello World");
+        assertEquals("", StringUtils.newStringUtf8(new Base16().decode(s2)), "StringToByte \"\"");
+        assertEquals("", StringUtils.newStringUtf8(new Base16().decode(s2)), "StringToByte static \"\"");
+        assertNull(StringUtils.newStringUtf8(new Base16().decode(s3)), "StringToByte null");
+        assertNull(StringUtils.newStringUtf8(new Base16().decode(s3)), "StringToByte static null");
     }
 
     private String toString(final byte[] data) {
@@ -480,10 +458,10 @@ public class Base16Test {
         return buf.toString();
     }
 
-    @Test(expected = IllegalArgumentException.class)
+    @Test
     public void checkEncodeLengthBounds() {
         final Base16 base16 = new Base16();
-        base16.encode(new byte[10], 0, 1 << 30);
+        assertThrows(IllegalArgumentException.class, () -> base16.encode(new byte[10], 0, 1 << 30));
     }
 
     @Test
@@ -585,13 +563,13 @@ public class Base16Test {
         assertEquals((byte)0xEF, context.buffer[0]);
     }
 
-    @Test(expected=IllegalArgumentException.class)
+    @Test
     public void testStrictDecoding() {
         final String encoded = "aabbccdde";  // Note the trailing `e` which does not make up a hex-pair and so is only 1/2 byte
 
         final Base16 b16 = new Base16(true, CodecPolicy.STRICT);
         assertEquals(CodecPolicy.STRICT, b16.getCodecPolicy());
-        b16.decode(StringUtils.getBytesUtf8(encoded));
+        assertThrows(IllegalArgumentException.class, () -> b16.decode(StringUtils.getBytesUtf8(encoded)));
     }
 
     @Test
@@ -604,4 +582,25 @@ public class Base16Test {
         final byte[] decoded = b16.decode(StringUtils.getBytesUtf8(encoded));
         assertArrayEquals(new byte[] {(byte)0xaa, (byte)0xbb, (byte)0xcc, (byte)0xdd}, decoded);
     }
+
+    @Test
+    public void testOddEvenDecoding() {
+        final String encoded = "4142434445";
+
+        final BaseNCodec.Context context = new BaseNCodec.Context();
+        final Base16 base16 = new Base16();
+
+        final byte[] encodedBytes = StringUtils.getBytesUtf8(encoded);
+
+        // pass odd, then even, then odd amount of data
+        base16.decode(encodedBytes, 0, 3, context);
+        base16.decode(encodedBytes, 3, 4, context);
+        base16.decode(encodedBytes, 7, 3, context);
+
+        final byte[] decodedBytes = new byte[context.pos];
+        System.arraycopy(context.buffer, context.readPos, decodedBytes, 0, decodedBytes.length);
+        final String decoded = StringUtils.newStringUtf8(decodedBytes);
+
+        assertEquals("ABCDE", decoded);
+    }
 }
