@@ -17,6 +17,13 @@
 
 package org.apache.commons.codec.binary;
 
+import static org.junit.jupiter.api.Assertions.assertArrayEquals;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertThrows;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+
 import java.io.BufferedReader;
 import java.io.ByteArrayInputStream;
 import java.io.ByteArrayOutputStream;
@@ -25,14 +32,7 @@ import java.io.InputStream;
 import java.io.InputStreamReader;
 
 import org.apache.commons.codec.CodecPolicy;
-import org.junit.Test;
-
-import static org.junit.Assert.assertArrayEquals;
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertNotNull;
-import static org.junit.Assert.assertTrue;
-import static org.junit.Assert.fail;
+import org.junit.jupiter.api.Test;
 
 /**
  * @since 1.4
@@ -91,15 +91,15 @@ public class Base64InputStreamTest {
      */
     @Test
     public void testCodec101() throws Exception {
-        final byte[] codec101 = StringUtils.getBytesUtf8(Base64TestData.CODEC_101_MULTIPLE_OF_3);
+        final byte[] codec101 = StringUtils.getBytesUtf8(Base64TestData.CODEC_101_INPUT_LENGTH_IS_MULTIPLE_OF_3);
         final ByteArrayInputStream bais = new ByteArrayInputStream(codec101);
         try (final Base64InputStream in = new Base64InputStream(bais)) {
             final byte[] result = new byte[8192];
             int c = in.read(result);
-            assertTrue("Codec101: First read successful [c=" + c + "]", c > 0);
+            assertTrue(c > 0, "Codec101: First read successful [c=" + c + "]");
 
             c = in.read(result);
-            assertTrue("Codec101: Second read should report end-of-stream [c=" + c + "]", c < 0);
+            assertTrue(c < 0, "Codec101: Second read should report end-of-stream [c=" + c + "]");
         }
     }
 
@@ -120,13 +120,13 @@ public class Base64InputStreamTest {
      */
     @Test
     public void testInputStreamReader() throws Exception {
-        final byte[] codec101 = StringUtils.getBytesUtf8(Base64TestData.CODEC_101_MULTIPLE_OF_3);
+        final byte[] codec101 = StringUtils.getBytesUtf8(Base64TestData.CODEC_101_INPUT_LENGTH_IS_MULTIPLE_OF_3);
         final ByteArrayInputStream bais = new ByteArrayInputStream(codec101);
         final Base64InputStream in = new Base64InputStream(bais);
         final InputStreamReader isr = new InputStreamReader(in);
         try (final BufferedReader br = new BufferedReader(isr)) {
             final String line = br.readLine();
-            assertNotNull("Codec101:  InputStreamReader works!", line);
+            assertNotNull(line, "Codec101:  InputStreamReader works!");
         }
     }
 
@@ -146,7 +146,7 @@ public class Base64InputStreamTest {
         final byte[] decodedBytes = BaseNTestData.streamToBytes(stream, new byte[1024]);
 
         final String decoded = StringUtils.newStringUtf8(decodedBytes);
-        assertEquals("codec-98 NPE Base64InputStream", Base64TestData.CODEC_98_NPE_DECODED, decoded);
+        assertEquals(Base64TestData.CODEC_98_NPE_DECODED, decoded, "codec-98 NPE Base64InputStream");
     }
 
     /**
@@ -192,8 +192,8 @@ public class Base64InputStreamTest {
     }
 
     private void testBase64EmptyInputStream(final int chuckSize) throws Exception {
-        final byte[] emptyEncoded = new byte[0];
-        final byte[] emptyDecoded = new byte[0];
+        final byte[] emptyEncoded = {};
+        final byte[] emptyDecoded = {};
         testByteByByte(emptyEncoded, emptyDecoded, chuckSize, CRLF);
         testByChunk(emptyEncoded, emptyDecoded, chuckSize, CRLF);
     }
@@ -222,12 +222,12 @@ public class Base64InputStreamTest {
         testByChunk(encoded, decoded, BaseNCodec.PEM_CHUNK_SIZE, LF);
 
         // Single Line test.
-        final String singleLine = Base64TestData.ENCODED_64_CHARS_PER_LINE.replaceAll("\n", "");
+        final String singleLine = Base64TestData.ENCODED_64_CHARS_PER_LINE.replace("\n", "");
         encoded = StringUtils.getBytesUtf8(singleLine);
         decoded = BaseNTestData.DECODED;
         testByChunk(encoded, decoded, 0, LF);
 
-        // test random data of sizes 0 thru 150
+        // test random data of sizes 0 through 150
         final BaseNCodec codec = new Base64(0, null, false);
         for (int i = 0; i <= 150; i++) {
             final byte[][] randomData = BaseNTestData.randomData(codec, i);
@@ -261,12 +261,12 @@ public class Base64InputStreamTest {
         testByteByByte(encoded, decoded, BaseNCodec.PEM_CHUNK_SIZE, LF);
 
         // Single Line test.
-        final String singleLine = Base64TestData.ENCODED_64_CHARS_PER_LINE.replaceAll("\n", "");
+        final String singleLine = Base64TestData.ENCODED_64_CHARS_PER_LINE.replace("\n", "");
         encoded = StringUtils.getBytesUtf8(singleLine);
         decoded = BaseNTestData.DECODED;
         testByteByByte(encoded, decoded, 0, LF);
 
-        // test random data of sizes 0 thru 150
+        // test random data of sizes 0 through 150
         final BaseNCodec codec = new Base64(0, null, false);
         for (int i = 0; i <= 150; i++) {
             final byte[][] randomData = BaseNTestData.randomData(codec, i);
@@ -301,21 +301,21 @@ public class Base64InputStreamTest {
         in = new Base64InputStream(new ByteArrayInputStream(decoded), true, chunkSize, separator);
         byte[] output = BaseNTestData.streamToBytes(in);
 
-        assertEquals("EOF", -1, in.read());
-        assertEquals("Still EOF", -1, in.read());
-        assertArrayEquals("Streaming base64 encode", encoded, output);
+        assertEquals(-1, in.read(), "EOF");
+        assertEquals(-1, in.read(), "Still EOF");
+        assertArrayEquals(encoded, output, "Streaming base64 encode");
 
         in.close();
 
-        // Now let's try decode.
+        // Now let's try to decode.
         in = new Base64InputStream(new ByteArrayInputStream(encoded));
         output = BaseNTestData.streamToBytes(in);
 
-        assertEquals("EOF", -1, in.read());
-        assertEquals("Still EOF", -1, in.read());
-        assertArrayEquals("Streaming base64 decode", decoded, output);
+        assertEquals(-1, in.read(), "EOF");
+        assertEquals(-1, in.read(), "Still EOF");
+        assertArrayEquals(decoded, output, "Streaming base64 decode");
 
-        // I always wanted to do this! (wrap encoder with decoder etc etc).
+        // I always wanted to do this! (wrap encoder with decoder etc.).
         in = new ByteArrayInputStream(decoded);
         for (int i = 0; i < 10; i++) {
             in = new Base64InputStream(in, true, chunkSize, separator);
@@ -323,9 +323,9 @@ public class Base64InputStreamTest {
         }
         output = BaseNTestData.streamToBytes(in);
 
-        assertEquals("EOF", -1, in.read());
-        assertEquals("Still EOF", -1, in.read());
-        assertArrayEquals("Streaming base64 wrap-wrap-wrap!", decoded, output);
+        assertEquals(-1, in.read(), "EOF");
+        assertEquals(-1, in.read(), "Still EOF");
+        assertArrayEquals(decoded, output, "Streaming base64 wrap-wrap-wrap!");
         in.close();
     }
 
@@ -357,25 +357,25 @@ public class Base64InputStreamTest {
             output[i] = (byte) in.read();
         }
 
-        assertEquals("EOF", -1, in.read());
-        assertEquals("Still EOF", -1, in.read());
-        assertArrayEquals("Streaming base64 encode", encoded, output);
+        assertEquals(-1, in.read(), "EOF");
+        assertEquals(-1, in.read(), "Still EOF");
+        assertArrayEquals(encoded, output, "Streaming base64 encode");
 
         in.close();
-        // Now let's try decode.
+        // Now let's try to decode.
         in = new Base64InputStream(new ByteArrayInputStream(encoded));
         output = new byte[decoded.length];
         for (int i = 0; i < output.length; i++) {
             output[i] = (byte) in.read();
         }
 
-        assertEquals("EOF", -1, in.read());
-        assertEquals("Still EOF", -1, in.read());
-        assertArrayEquals("Streaming base64 decode", decoded, output);
+        assertEquals(-1, in.read(), "EOF");
+        assertEquals(-1, in.read(), "Still EOF");
+        assertArrayEquals(decoded, output, "Streaming base64 decode");
 
         in.close();
 
-        // I always wanted to do this! (wrap encoder with decoder etc etc).
+        // I always wanted to do this! (wrap encoder with decoder etc.).
         in = new ByteArrayInputStream(decoded);
         for (int i = 0; i < 10; i++) {
             in = new Base64InputStream(in, true, chunkSize, separator);
@@ -386,9 +386,9 @@ public class Base64InputStreamTest {
             output[i] = (byte) in.read();
         }
 
-        assertEquals("EOF", -1, in.read());
-        assertEquals("Still EOF", -1, in.read());
-        assertArrayEquals("Streaming base64 wrap-wrap-wrap!", decoded, output);
+        assertEquals(-1, in.read(), "EOF");
+        assertEquals(-1, in.read(), "Still EOF");
+        assertArrayEquals(decoded, output, "Streaming base64 wrap-wrap-wrap!");
         in.close();
     }
 
@@ -404,10 +404,34 @@ public class Base64InputStreamTest {
         final ByteArrayInputStream bin = new ByteArrayInputStream(decoded);
         try (final Base64InputStream in = new Base64InputStream(bin, true, 4, new byte[] { 0, 0, 0 })) {
             // Always returns false for now.
-            assertFalse("Base64InputStream.markSupported() is false", in.markSupported());
+            assertFalse(in.markSupported(), "Base64InputStream.markSupported() is false");
         }
     }
 
+    /**
+     * Tests read using different buffer sizes
+     *
+     * @throws Exception
+     *             for some failure scenarios.
+     */
+    @Test
+    public void testReadMultipleBufferSizes() throws Exception {
+        final byte[][] randomData = BaseNTestData.randomData(new Base64(0, null, false), 1024 * 64);
+        final byte[] encoded = randomData[1];
+        final byte[] decoded = randomData[0];
+        final ByteArrayInputStream bin = new ByteArrayInputStream(encoded);
+        final ByteArrayOutputStream out = new ByteArrayOutputStream();
+        try (final Base64InputStream in = new Base64InputStream(bin)) {
+            for (final int i : new int[] { 4 * 1024, 4 * 1024, 8 * 1024, 8 * 1024, 16 * 1024, 16 * 1024, 8 * 1024 }) {
+                final byte[] buf = new byte[i];
+                final int bytesRead = in.read(buf);
+                assertEquals(i, bytesRead);
+                out.write(buf, 0, bytesRead);
+            }
+        }
+        assertArrayEquals(decoded, out.toByteArray());
+    }
+
     /**
      * Tests read returning 0
      *
@@ -422,7 +446,7 @@ public class Base64InputStreamTest {
         final ByteArrayInputStream bin = new ByteArrayInputStream(decoded);
         try (final Base64InputStream in = new Base64InputStream(bin, true, 4, new byte[] { 0, 0, 0 })) {
             bytesRead = in.read(buf, 0, 0);
-            assertEquals("Base64InputStream.read(buf, 0, 0) returns 0", 0, bytesRead);
+            assertEquals(0, bytesRead, "Base64InputStream.read(buf, 0, 0) returns 0");
         }
     }
 
@@ -437,10 +461,7 @@ public class Base64InputStreamTest {
         final byte[] decoded = StringUtils.getBytesUtf8(STRING_FIXTURE);
         final ByteArrayInputStream bin = new ByteArrayInputStream(decoded);
         try (final Base64InputStream in = new Base64InputStream(bin, true, 4, new byte[] { 0, 0, 0 })) {
-            in.read(null, 0, 0);
-            fail("Base64InputStream.read(null, 0, 0) to throw a NullPointerException");
-        } catch (final NullPointerException e) {
-            // Expected
+            assertThrows(NullPointerException.class, () -> in.read(null, 0, 0));
         }
     }
 
@@ -455,35 +476,11 @@ public class Base64InputStreamTest {
         final byte[] decoded = StringUtils.getBytesUtf8(STRING_FIXTURE);
         final byte[] buf = new byte[1024];
         final ByteArrayInputStream bin = new ByteArrayInputStream(decoded);
-        try (final Base64InputStream in = new Base64InputStream(bin, true, 4, new byte[] { 0, 0, 0 })) {
-
-            try {
-                in.read(buf, -1, 0);
-                fail("Expected Base64InputStream.read(buf, -1, 0) to throw IndexOutOfBoundsException");
-            } catch (final IndexOutOfBoundsException e) {
-                // Expected
-            }
-
-            try {
-                in.read(buf, 0, -1);
-                fail("Expected Base64InputStream.read(buf, 0, -1) to throw IndexOutOfBoundsException");
-            } catch (final IndexOutOfBoundsException e) {
-                // Expected
-            }
-
-            try {
-                in.read(buf, buf.length + 1, 0);
-                fail("Base64InputStream.read(buf, buf.length + 1, 0) throws IndexOutOfBoundsException");
-            } catch (final IndexOutOfBoundsException e) {
-                // Expected
-            }
-
-            try {
-                in.read(buf, buf.length - 1, 2);
-                fail("Base64InputStream.read(buf, buf.length - 1, 2) throws IndexOutOfBoundsException");
-            } catch (final IndexOutOfBoundsException e) {
-                // Expected
-            }
+        try (final Base64InputStream in = new Base64InputStream(bin, true, 4, new byte[] {0, 0, 0})) {
+            assertThrows(IndexOutOfBoundsException.class, () -> in.read(buf, -1, 0), "Base64InputStream.read(buf, -1, 0)");
+            assertThrows(IndexOutOfBoundsException.class, () -> in.read(buf, 0, -1), "Base64InputStream.read(buf, 0, -1)");
+            assertThrows(IndexOutOfBoundsException.class, () -> in.read(buf, buf.length + 1, 0), "Base64InputStream.read(buf, buf.length + 1, 0)");
+            assertThrows(IndexOutOfBoundsException.class, () -> in.read(buf, buf.length - 1, 2), "Base64InputStream.read(buf, buf.length - 1, 2)");
         }
     }
 
@@ -565,11 +562,11 @@ public class Base64InputStreamTest {
      * @throws Throwable
      *             for some failure scenarios.
      */
-    @Test(expected=IllegalArgumentException.class)
+    @Test
     public void testSkipWrongArgument() throws Throwable {
         final InputStream ins = new ByteArrayInputStream(StringUtils.getBytesIso8859_1(ENCODED_B64));
         try (final Base64InputStream b64stream = new Base64InputStream(ins)) {
-            b64stream.skip(-10);
+            assertThrows(IllegalArgumentException.class, () -> b64stream.skip(-10));
         }
     }
 
@@ -583,20 +580,15 @@ public class Base64InputStreamTest {
     public void testStrictDecoding() throws Exception {
         for (final String s : Base64Test.BASE64_IMPOSSIBLE_CASES) {
             final byte[] encoded = StringUtils.getBytesUtf8(s);
-            Base64InputStream in = new Base64InputStream(new ByteArrayInputStream(encoded), false);
+            final Base64InputStream in = new Base64InputStream(new ByteArrayInputStream(encoded), false);
             // Default is lenient decoding; it should not throw
             assertFalse(in.isStrictDecoding());
             BaseNTestData.streamToBytes(in);
 
             // Strict decoding should throw
-            in = new Base64InputStream(new ByteArrayInputStream(encoded), false, 0, null, CodecPolicy.STRICT);
-            assertTrue(in.isStrictDecoding());
-            try {
-                BaseNTestData.streamToBytes(in);
-                fail();
-            } catch (final IllegalArgumentException ex) {
-                // expected
-            }
+            final Base64InputStream in2 = new Base64InputStream(new ByteArrayInputStream(encoded), false, 0, null, CodecPolicy.STRICT);
+            assertTrue(in2.isStrictDecoding());
+            assertThrows(IllegalArgumentException.class, () -> BaseNTestData.streamToBytes(in2));
         }
     }
 }
