@@ -17,12 +17,14 @@
 
 package org.apache.commons.codec.binary;
 
-import static org.junit.Assert.assertArrayEquals;
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertNotNull;
-import static org.junit.Assert.assertTrue;
-import static org.junit.Assert.fail;
+import static org.junit.jupiter.api.Assertions.assertArrayEquals;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertNull;
+import static org.junit.jupiter.api.Assertions.assertThrows;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+import static org.junit.jupiter.api.Assertions.fail;
 
 import java.math.BigInteger;
 import java.nio.charset.Charset;
@@ -34,8 +36,8 @@ import org.apache.commons.codec.CodecPolicy;
 import org.apache.commons.codec.DecoderException;
 import org.apache.commons.codec.EncoderException;
 import org.apache.commons.lang3.ArrayUtils;
-import org.junit.Assume;
-import org.junit.Test;
+import org.junit.jupiter.api.Assumptions;
+import org.junit.jupiter.api.Test;
 
 /**
  * Test cases for Base64 class.
@@ -87,19 +89,14 @@ public class Base64Test {
         final String nullString = null;
         final String emptyString = "";
         final String validString = "abc===defg\n\r123456\r789\r\rABC\n\nDEF==GHI\r\nJKL==============";
-        final String invalidString = validString + (char) 0; // append null
-                                                                // character
+        final String invalidString = validString + (char) 0; // append null character
 
-        try {
-            Base64.isBase64(nullString);
-            fail("Base64.isStringBase64() should not be null-safe.");
-        } catch (final NullPointerException npe) {
-            assertNotNull("Base64.isStringBase64() should not be null-safe.", npe);
-        }
+        assertThrows(NullPointerException.class, () -> Base64.isBase64(nullString),
+                "Base64.isStringBase64() should not be null-safe.");
 
-        assertTrue("Base64.isStringBase64(empty-string) is true", Base64.isBase64(emptyString));
-        assertTrue("Base64.isStringBase64(valid-string) is true", Base64.isBase64(validString));
-        assertFalse("Base64.isStringBase64(invalid-string) is false", Base64.isBase64(invalidString));
+        assertTrue(Base64.isBase64(emptyString), "Base64.isStringBase64(empty-string) is true");
+        assertTrue(Base64.isBase64(validString), "Base64.isStringBase64(valid-string) is true");
+        assertFalse(Base64.isBase64(invalidString), "Base64.isStringBase64(invalid-string) is false");
     }
 
     /**
@@ -111,7 +108,7 @@ public class Base64Test {
         String encodedContent;
         byte[] encodedBytes = Base64.encodeBase64(StringUtils.getBytesUtf8(content));
         encodedContent = StringUtils.newStringUtf8(encodedBytes);
-        assertEquals("encoding hello world", "SGVsbG8gV29ybGQ=", encodedContent);
+        assertEquals("SGVsbG8gV29ybGQ=", encodedContent, "encoding hello world");
 
         Base64 b64 = new Base64(BaseNCodec.MIME_CHUNK_SIZE, null); // null
                                                                     // lineSeparator
@@ -120,18 +117,18 @@ public class Base64Test {
                                                                     // no-chunking
         encodedBytes = b64.encode(StringUtils.getBytesUtf8(content));
         encodedContent = StringUtils.newStringUtf8(encodedBytes);
-        assertEquals("encoding hello world", "SGVsbG8gV29ybGQ=", encodedContent);
+        assertEquals("SGVsbG8gV29ybGQ=", encodedContent, "encoding hello world");
 
         b64 = new Base64(0, null); // null lineSeparator same as saying
                                     // no-chunking
         encodedBytes = b64.encode(StringUtils.getBytesUtf8(content));
         encodedContent = StringUtils.newStringUtf8(encodedBytes);
-        assertEquals("encoding hello world", "SGVsbG8gV29ybGQ=", encodedContent);
+        assertEquals("SGVsbG8gV29ybGQ=", encodedContent, "encoding hello world");
 
         // bogus characters to decode (to skip actually) {e-acute*6}
         final byte[] decode = b64.decode("SGVsbG{\u00e9\u00e9\u00e9\u00e9\u00e9\u00e9}8gV29ybGQ=");
         final String decodeString = StringUtils.newStringUtf8(decode);
-        assertEquals("decode hello world", "Hello World", decodeString);
+        assertEquals("Hello World", decodeString, "decode hello world");
     }
 
     @Test
@@ -151,13 +148,13 @@ public class Base64Test {
 
     private void testBase64InBuffer(final int startPasSize, final int endPadSize) {
         final String content = "Hello World";
-        String encodedContent;
+        final String encodedContent;
         final byte[] bytesUtf8 = StringUtils.getBytesUtf8(content);
         byte[] buffer = ArrayUtils.addAll(bytesUtf8, new byte[endPadSize]);
         buffer = ArrayUtils.addAll(new byte[startPasSize], buffer);
         final byte[] encodedBytes = new Base64().encode(buffer, startPasSize, bytesUtf8.length);
         encodedContent = StringUtils.newStringUtf8(encodedBytes);
-        assertEquals("encoding hello world", "SGVsbG8gV29ybGQ=", encodedContent);
+        assertEquals("SGVsbG8gV29ybGQ=", encodedContent, "encoding hello world");
     }
 
     /**
@@ -178,7 +175,7 @@ public class Base64Test {
         final String content = "SGVsbG8gV29ybGQ=SGVsbG8gV29ybGQ=";
         final byte[] result = Base64.decodeBase64(content);
         final byte[] shouldBe = StringUtils.getBytesUtf8("Hello World");
-        assertTrue("decode should halt at pad (=)", Arrays.equals(result, shouldBe));
+        assertArrayEquals(result, shouldBe, "decode should halt at pad (=)");
     }
 
     /**
@@ -190,9 +187,9 @@ public class Base64Test {
         // convert to "\r\n" so we're equal to the old openssl encoding test
         // stored
         // in Base64TestData.ENCODED_76_CHARS_PER_LINE:
-        final String actualResult = Base64TestData.ENCODED_76_CHARS_PER_LINE.replaceAll("\n", "\r\n");
+        final String actualResult = Base64TestData.ENCODED_76_CHARS_PER_LINE.replace("\n", "\r\n");
         final byte[] actualEncode = StringUtils.getBytesUtf8(actualResult);
-        assertTrue("chunkedEncodeMultipleOf76", Arrays.equals(expectedEncode, actualEncode));
+        assertArrayEquals(expectedEncode, actualEncode, "chunkedEncodeMultipleOf76");
     }
 
     /**
@@ -201,7 +198,7 @@ public class Base64Test {
      */
     @Test
     public void testCodec68() {
-        final byte[] x = new byte[] { 'n', 'A', '=', '=', (byte) 0x9c };
+        final byte[] x = { 'n', 'A', '=', '=', (byte) 0x9c };
         Base64.decodeBase64(x);
     }
 
@@ -225,11 +222,12 @@ public class Base64Test {
 
     @Test
     public void testCodeInteger3() {
-        final String encodedInt3 = "FKIhdgaG5LGKiEtF1vHy4f3y700zaD6QwDS3IrNVGzNp2"
-                + "rY+1LFWTK6D44AyiC1n8uWz1itkYMZF0/aKDK0Yjg==";
+        final String encodedInt3 = "FKIhdgaG5LGKiEtF1vHy4f3y700zaD6QwDS3IrNVGzNp2" +
+            "rY+1LFWTK6D44AyiC1n8uWz1itkYMZF0/aKDK0Yjg==";
         final BigInteger bigInt3 = new BigInteger(
-                "10806548154093873461951748545" + "1196989136416448805819079363524309897749044958112417136240557"
-                        + "4495062430572478766856090958495998158114332651671116876320938126");
+            "10806548154093873461951748545" +
+            "1196989136416448805819079363524309897749044958112417136240557" +
+            "4495062430572478766856090958495998158114332651671116876320938126");
 
         assertEquals(encodedInt3, new String(Base64.encodeInteger(bigInt3)));
         assertEquals(bigInt3, Base64.decodeInteger(encodedInt3.getBytes(CHARSET_UTF8)));
@@ -237,15 +235,16 @@ public class Base64Test {
 
     @Test
     public void testCodeInteger4() {
-        final String encodedInt4 = "ctA8YGxrtngg/zKVvqEOefnwmViFztcnPBYPlJsvh6yKI"
-                + "4iDm68fnp4Mi3RrJ6bZAygFrUIQLxLjV+OJtgJAEto0xAs+Mehuq1DkSFEpP3o"
-                + "DzCTOsrOiS1DwQe4oIb7zVk/9l7aPtJMHW0LVlMdwZNFNNJoqMcT2ZfCPrfvYv" + "Q0=";
-        final BigInteger bigInt4 = new BigInteger(
-                "80624726256040348115552042320" + "6968135001872753709424419772586693950232350200555646471175944"
-                        + "519297087885987040810778908507262272892702303774422853675597"
-                        + "748008534040890923814202286633163248086055216976551456088015"
-                        + "338880713818192088877057717530169381044092839402438015097654"
-                        + "53542091716518238707344493641683483917");
+        final String encodedInt4 = "ctA8YGxrtngg/zKVvqEOefnwmViFztcnPBYPlJsvh6yKI" +
+            "4iDm68fnp4Mi3RrJ6bZAygFrUIQLxLjV+OJtgJAEto0xAs+Mehuq1DkSFEpP3o" +
+            "DzCTOsrOiS1DwQe4oIb7zVk/9l7aPtJMHW0LVlMdwZNFNNJoqMcT2ZfCPrfvYv" +
+            "Q0=";
+        final BigInteger bigInt4 = new BigInteger("80624726256040348115552042320" +
+            "6968135001872753709424419772586693950232350200555646471175944" +
+            "519297087885987040810778908507262272892702303774422853675597" +
+            "748008534040890923814202286633163248086055216976551456088015" +
+            "338880713818192088877057717530169381044092839402438015097654" +
+            "53542091716518238707344493641683483917");
 
         assertEquals(encodedInt4, new String(Base64.encodeInteger(bigInt4)));
         assertEquals(bigInt4, Base64.decodeInteger(encodedInt4.getBytes(CHARSET_UTF8)));
@@ -258,14 +257,8 @@ public class Base64Test {
 
     @Test
     public void testCodeIntegerNull() {
-        try {
-            Base64.encodeInteger(null);
-            fail("Exception not thrown when passing in null to encodeInteger(BigInteger)");
-        } catch (final NullPointerException npe) {
-            // expected
-        } catch (final Exception e) {
-            fail("Incorrect Exception caught when passing in null to encodeInteger(BigInteger)");
-        }
+        assertThrows(NullPointerException.class, () -> Base64.encodeInteger(null),
+                "Exception not thrown when passing in null to encodeInteger(BigInteger)");
     }
 
     @Test
@@ -275,34 +268,25 @@ public class Base64Test {
         base64 = new Base64(-1);
         base64 = new Base64(-1, new byte[] {});
         base64 = new Base64(64, new byte[] {});
-        try {
-            base64 = new Base64(-1, new byte[] { 'A' }); // TODO do we need to
-                                                            // check sep if len
-                                                            // = -1?
-            fail("Should have rejected attempt to use 'A' as a line separator");
-        } catch (final IllegalArgumentException ignored) {
-            // Expected
-        }
-        try {
-            base64 = new Base64(64, new byte[] { 'A' });
-            fail("Should have rejected attempt to use 'A' as a line separator");
-        } catch (final IllegalArgumentException ignored) {
-            // Expected
-        }
-        try {
-            base64 = new Base64(64, new byte[] { '=' });
-            fail("Should have rejected attempt to use '=' as a line separator");
-        } catch (final IllegalArgumentException ignored) {
-            // Expected
-        }
+        base64 = new Base64(64, new byte[] {'$'}); // OK
+
+        assertThrows(IllegalArgumentException.class, () -> new Base64(-1, new byte[] { 'A' }),
+                "Should have rejected attempt to use 'A' as a line separator");
+        // TODO do we need to check sep if len = -1?
+
+        assertThrows(IllegalArgumentException.class, () -> new Base64(64, new byte[] { 'A' }),
+                "Should have rejected attempt to use 'A' as a line separator");
+
+        assertThrows(IllegalArgumentException.class, () -> new Base64(64, new byte[] { '=' }),
+                "Should have rejected attempt to use '=' as a line separator");
+
         base64 = new Base64(64, new byte[] { '$' }); // OK
-        try {
-            base64 = new Base64(64, new byte[] { 'A', '$' });
-            fail("Should have rejected attempt to use 'A$' as a line separator");
-        } catch (final IllegalArgumentException ignored) {
-            // Expected
-        }
+
+        assertThrows(IllegalArgumentException.class, () -> new Base64(64, new byte[] { 'A', '$' }),
+                "Should have rejected attempt to use 'A$' as a line separator");
+
         base64 = new Base64(64, new byte[] { ' ', '$', '\n', '\r', '\t' }); // OK
+
         assertNotNull(base64);
     }
 
@@ -313,7 +297,7 @@ public class Base64Test {
         String expectedResult = Base64TestData.ENCODED_64_CHARS_PER_LINE;
         expectedResult = expectedResult.replace('\n', '\t');
         final String result = StringUtils.newStringUtf8(encoded);
-        assertEquals("new Base64(65, \\t, false)", expectedResult, result);
+        assertEquals(expectedResult, result, "new Base64(65, \\t, false)");
     }
 
     @Test
@@ -322,13 +306,13 @@ public class Base64Test {
         final Base64 base64 = new Base64(64, new byte[] { '\t' }, true);
         final byte[] encoded = base64.encode(BaseNTestData.DECODED);
         String expectedResult = Base64TestData.ENCODED_64_CHARS_PER_LINE;
-        expectedResult = expectedResult.replaceAll("=", ""); // url-safe has no
+        expectedResult = expectedResult.replace("=", ""); // url-safe has no
                                                                 // == padding.
         expectedResult = expectedResult.replace('\n', '\t');
         expectedResult = expectedResult.replace('+', '-');
         expectedResult = expectedResult.replace('/', '_');
         final String result = StringUtils.newStringUtf8(encoded);
-        assertEquals("new Base64(64, \\t, true)", result, expectedResult);
+        assertEquals(result, expectedResult, "new Base64(64, \\t, true)");
     }
 
     /**
@@ -388,7 +372,7 @@ public class Base64Test {
 
         final String dest = new String(decodedWithWS);
 
-        assertEquals("Dest string doesn't equal the original", orig, dest);
+        assertEquals(orig, dest, "Dest string doesn't equal the original");
     }
 
     /**
@@ -396,18 +380,18 @@ public class Base64Test {
      */
     @Test
     public void testEmptyBase64() {
-        byte[] empty = new byte[0];
+        byte[] empty = {};
         byte[] result = Base64.encodeBase64(empty);
-        assertEquals("empty base64 encode", 0, result.length);
-        assertEquals("empty base64 encode", null, Base64.encodeBase64(null));
+        assertEquals(0, result.length, "empty base64 encode");
+        assertNull(Base64.encodeBase64(null), "empty base64 encode");
         result = new Base64().encode(empty, 0, 1);
-        assertEquals("empty base64 encode", 0, result.length);
-        assertEquals("empty base64 encode", null, new Base64().encode(null, 0, 1));
+        assertEquals(0, result.length, "empty base64 encode");
+        assertNull(new Base64().encode(null, 0, 1), "empty base64 encode");
 
         empty = new byte[0];
         result = Base64.decodeBase64(empty);
-        assertEquals("empty base64 decode", 0, result.length);
-        assertEquals("empty base64 encode", null, Base64.decodeBase64((byte[]) null));
+        assertEquals(0, result.length, "empty base64 decode");
+        assertNull(Base64.decodeBase64((byte[]) null), "empty base64 encode");
     }
 
     // encode/decode a large random array
@@ -419,7 +403,7 @@ public class Base64Test {
             final byte[] enc = Base64.encodeBase64(data);
             assertTrue(Base64.isBase64(enc));
             final byte[] data2 = Base64.decodeBase64(enc);
-            assertTrue(Arrays.equals(data, data2));
+            assertArrayEquals(data, data2);
         }
     }
 
@@ -430,9 +414,9 @@ public class Base64Test {
             final byte[] data = new byte[i];
             this.getRandom().nextBytes(data);
             final byte[] enc = Base64.encodeBase64(data);
-            assertTrue("\"" + new String(enc) + "\" is Base64 data.", Base64.isBase64(enc));
+            assertTrue(Base64.isBase64(enc), "\"" + new String(enc) + "\" is Base64 data.");
             final byte[] data2 = Base64.decodeBase64(enc);
-            assertTrue(toString(data) + " equals " + toString(data2), Arrays.equals(data, data2));
+            assertArrayEquals(data, data2, toString(data) + " equals " + toString(data2));
         }
     }
 
@@ -446,18 +430,14 @@ public class Base64Test {
 
     @Test
     public void testCodec112() { // size calculation assumes always chunked
-        final byte[] in = new byte[] { 0 };
+        final byte[] in = { 0 };
         final byte[] out = Base64.encodeBase64(in);
         Base64.encodeBase64(in, false, false, out.length);
+        // TODO Assert??
     }
 
-    private void testEncodeOverMaxSize(final int maxSize) throws Exception {
-        try {
-            Base64.encodeBase64(BaseNTestData.DECODED, true, false, maxSize);
-            fail("Expected " + IllegalArgumentException.class.getName());
-        } catch (final IllegalArgumentException e) {
-            // Expected
-        }
+    private void testEncodeOverMaxSize(final int maxSize) {
+        assertThrows(IllegalArgumentException.class, () -> Base64.encodeBase64(BaseNTestData.DECODED, true, false, maxSize));
     }
 
     @Test
@@ -476,10 +456,14 @@ public class Base64Test {
         assertFalse(Base64.isBase64(new byte[] { 0 }));
         assertFalse(Base64.isBase64(new byte[] { 64, Byte.MAX_VALUE }));
         assertFalse(Base64.isBase64(new byte[] { Byte.MAX_VALUE }));
+
         assertTrue(Base64.isBase64(new byte[] { 'A' }));
+
         assertFalse(Base64.isBase64(new byte[] { 'A', Byte.MIN_VALUE }));
+
         assertTrue(Base64.isBase64(new byte[] { 'A', 'Z', 'a' }));
         assertTrue(Base64.isBase64(new byte[] { '/', '=', '+' }));
+
         assertFalse(Base64.isBase64(new byte[] { '$' }));
     }
 
@@ -491,11 +475,11 @@ public class Base64Test {
         final Base64 base64Standard = new Base64(false);
         final Base64 base64URLSafe = new Base64(true);
 
-        assertFalse("Base64.isUrlSafe=false", base64Standard.isUrlSafe());
-        assertTrue("Base64.isUrlSafe=true", base64URLSafe.isUrlSafe());
+        assertFalse(base64Standard.isUrlSafe(), "Base64.isUrlSafe=false");
+        assertTrue(base64URLSafe.isUrlSafe(), "Base64.isUrlSafe=true");
 
         final byte[] whiteSpace = { ' ', '\n', '\r', '\t' };
-        assertTrue("Base64.isBase64(whiteSpace)=true", Base64.isBase64(whiteSpace));
+        assertTrue(Base64.isBase64(whiteSpace), "Base64.isBase64(whiteSpace)=true");
     }
 
     @Test
@@ -538,33 +522,26 @@ public class Base64Test {
 
         final byte[] bArray = { '%' };
 
-        assertFalse("Invalid Base64 array was incorrectly validated as " + "an array of Base64 encoded data",
-                Base64.isBase64(bArray));
+        assertFalse(Base64.isBase64(bArray),
+                "Invalid Base64 array was incorrectly validated as an array of Base64 encoded data");
 
         try {
             final Base64 b64 = new Base64();
             final byte[] result = b64.decode(bArray);
 
-            assertEquals("The result should be empty as the test encoded content did "
-                    + "not contain any valid base 64 characters", 0, result.length);
+            assertEquals(0, result.length, "The result should be empty as the test encoded content did " +
+                    "not contain any valid base 64 characters");
         } catch (final Exception e) {
-            fail("Exception was thrown when trying to decode "
-                    + "invalid base64 encoded data - RFC 2045 requires that all "
-                    + "non base64 character be discarded, an exception should not" + " have been thrown");
+            fail("Exception '" + e.getClass().getName() + "' was thrown when trying to decode " +
+                "invalid base64 encoded data - RFC 2045 requires that all " +
+                "non base64 character be discarded, an exception should not have been thrown");
         }
     }
 
     @Test
-    public void testObjectDecodeWithInvalidParameter() throws Exception {
-        final Base64 b64 = new Base64();
-
-        try {
-            b64.decode(Integer.valueOf(5));
-            fail("decode(Object) didn't throw an exception when passed an Integer object");
-        } catch (final DecoderException e) {
-            // ignored
-        }
-
+    public void testObjectDecodeWithInvalidParameter() {
+        assertThrows(DecoderException.class, () -> new Base64().decode(Integer.valueOf(5)),
+            "decode(Object) didn't throw an exception when passed an Integer object");
     }
 
     @Test
@@ -578,18 +555,13 @@ public class Base64Test {
         final byte[] baDecoded = (byte[]) oDecoded;
         final String dest = new String(baDecoded);
 
-        assertEquals("dest string does not equal original", original, dest);
+        assertEquals(original, dest, "dest string does not equal original");
     }
 
     @Test
-    public void testObjectEncodeWithInvalidParameter() throws Exception {
-        final Base64 b64 = new Base64();
-        try {
-            b64.encode("Yadayadayada");
-            fail("encode(Object) didn't throw an exception when passed a String object");
-        } catch (final EncoderException e) {
-            // Expected
-        }
+    public void testObjectEncodeWithInvalidParameter() {
+        assertThrows(EncoderException.class, () -> new Base64().encode("Yadayadayada"),
+                "encode(Object) didn't throw an exception when passed a String object");
     }
 
     @Test
@@ -603,7 +575,7 @@ public class Base64Test {
         final byte[] bArray = Base64.decodeBase64((byte[]) oEncoded);
         final String dest = new String(bArray);
 
-        assertEquals("dest string does not equal original", original, dest);
+        assertEquals(original, dest, "dest string does not equal original");
     }
 
     @Test
@@ -617,7 +589,7 @@ public class Base64Test {
         assertEquals("AAA=", new String(Base64.encodeBase64(new byte[] { 0, 0 })));
         for (int i = -128; i <= 127; i++) {
             final byte test[] = { (byte) i, (byte) i };
-            assertTrue(Arrays.equals(test, Base64.decodeBase64(Base64.encodeBase64(test))));
+            assertArrayEquals(test, Base64.decodeBase64(Base64.encodeBase64(test)));
         }
     }
 
@@ -626,7 +598,7 @@ public class Base64Test {
      */
     @Test
     public void testRfc2045Section2Dot1CrLfDefinition() {
-        assertTrue(Arrays.equals(new byte[] { 13, 10 }, Base64.CHUNK_SEPARATOR));
+        assertArrayEquals(new byte[]{13, 10}, BaseNCodec.CHUNK_SEPARATOR);
     }
 
     /**
@@ -688,7 +660,7 @@ public class Base64Test {
      */
     @Test
     public void testRfc4648Section10DecodeWithCrLf() {
-        final String CRLF = StringUtils.newStringUsAscii(Base64.CHUNK_SEPARATOR);
+        final String CRLF = StringUtils.newStringUsAscii(BaseNCodec.CHUNK_SEPARATOR);
         assertEquals("", StringUtils.newStringUsAscii(Base64.decodeBase64("" + CRLF)));
         assertEquals("f", StringUtils.newStringUsAscii(Base64.decodeBase64("Zg==" + CRLF)));
         assertEquals("fo", StringUtils.newStringUsAscii(Base64.decodeBase64("Zm8=" + CRLF)));
@@ -897,7 +869,7 @@ public class Base64Test {
         assertEquals("aA==", new String(Base64.encodeBase64(new byte[] { (byte) 104 })));
         for (int i = -128; i <= 127; i++) {
             final byte test[] = { (byte) i };
-            assertTrue(Arrays.equals(test, Base64.decodeBase64(Base64.encodeBase64(test))));
+            assertArrayEquals(test, Base64.decodeBase64(Base64.encodeBase64(test)));
         }
     }
 
@@ -1147,21 +1119,21 @@ public class Base64Test {
     }
 
     /**
-     * Tests url-safe Base64 against random data, sizes 0 to 150.
+     * Tests URL-safe Base64 against random data, sizes 0 to 150.
      */
     @Test
     public void testUrlSafe() {
-        // test random data of sizes 0 thru 150
+        // test random data of sizes 0 through 150
         final BaseNCodec codec = new Base64(true);
         for (int i = 0; i <= 150; i++) {
             final byte[][] randomData = BaseNTestData.randomData(codec, i);
             final byte[] encoded = randomData[1];
             final byte[] decoded = randomData[0];
             final byte[] result = Base64.decodeBase64(encoded);
-            assertTrue("url-safe i=" + i, Arrays.equals(decoded, result));
-            assertFalse("url-safe i=" + i + " no '='", BaseNTestData.bytesContain(encoded, (byte) '='));
-            assertFalse("url-safe i=" + i + " no '\\'", BaseNTestData.bytesContain(encoded, (byte) '\\'));
-            assertFalse("url-safe i=" + i + " no '+'", BaseNTestData.bytesContain(encoded, (byte) '+'));
+            assertArrayEquals(decoded, result, "url-safe i=" + i);
+            assertFalse(BaseNTestData.bytesContain(encoded, (byte) '='), "url-safe i=" + i + " no '='");
+            assertFalse(BaseNTestData.bytesContain(encoded, (byte) '\\'), "url-safe i=" + i + " no '\\'");
+            assertFalse(BaseNTestData.bytesContain(encoded, (byte) '+'), "url-safe i=" + i + " no '+'");
         }
 
     }
@@ -1242,12 +1214,12 @@ public class Base64Test {
 //                        + StringUtils.newStringUtf8(urlSafe3[i]) + "]");
 //            }
 
-            assertTrue("standard encode uuid", Arrays.equals(encodedStandard, standard[i]));
-            assertTrue("url-safe encode uuid", Arrays.equals(encodedUrlSafe, urlSafe3[i]));
-            assertTrue("standard decode uuid", Arrays.equals(decodedStandard, ids[i]));
-            assertTrue("url-safe1 decode uuid", Arrays.equals(decodedUrlSafe1, ids[i]));
-            assertTrue("url-safe2 decode uuid", Arrays.equals(decodedUrlSafe2, ids[i]));
-            assertTrue("url-safe3 decode uuid", Arrays.equals(decodedUrlSafe3, ids[i]));
+            assertArrayEquals(encodedStandard, standard[i], "standard encode uuid");
+            assertArrayEquals(encodedUrlSafe, urlSafe3[i], "url-safe encode uuid");
+            assertArrayEquals(decodedStandard, ids[i], "standard decode uuid");
+            assertArrayEquals(decodedUrlSafe1, ids[i], "url-safe1 decode uuid");
+            assertArrayEquals(decodedUrlSafe2, ids[i], "url-safe2 decode uuid");
+            assertArrayEquals(decodedUrlSafe3, ids[i], "url-safe3 decode uuid");
         }
     }
 
@@ -1255,22 +1227,30 @@ public class Base64Test {
     public void testByteToStringVariations() throws DecoderException {
         final Base64 base64 = new Base64(0);
         final byte[] b1 = StringUtils.getBytesUtf8("Hello World");
-        final byte[] b2 = new byte[0];
+        final byte[] b2 = {};
         final byte[] b3 = null;
         final byte[] b4 = Hex.decodeHex("2bf7cc2701fe4397b49ebeed5acc7090"); // for
                                                                                             // url-safe
                                                                                             // tests
 
-        assertEquals("byteToString Hello World", "SGVsbG8gV29ybGQ=", base64.encodeToString(b1));
-        assertEquals("byteToString static Hello World", "SGVsbG8gV29ybGQ=", Base64.encodeBase64String(b1));
-        assertEquals("byteToString \"\"", "", base64.encodeToString(b2));
-        assertEquals("byteToString static \"\"", "", Base64.encodeBase64String(b2));
-        assertEquals("byteToString null", null, base64.encodeToString(b3));
-        assertEquals("byteToString static null", null, Base64.encodeBase64String(b3));
-        assertEquals("byteToString UUID", "K/fMJwH+Q5e0nr7tWsxwkA==", base64.encodeToString(b4));
-        assertEquals("byteToString static UUID", "K/fMJwH+Q5e0nr7tWsxwkA==", Base64.encodeBase64String(b4));
-        assertEquals("byteToString static-url-safe UUID", "K_fMJwH-Q5e0nr7tWsxwkA",
-                Base64.encodeBase64URLSafeString(b4));
+        assertEquals("SGVsbG8gV29ybGQ=", base64.encodeToString(b1),
+                "byteToString Hello World");
+        assertEquals( "SGVsbG8gV29ybGQ=", Base64.encodeBase64String(b1),
+                "byteToString static Hello World");
+        assertEquals("", base64.encodeToString(b2),
+                "byteToString \"\"");
+        assertEquals("", Base64.encodeBase64String(b2),
+                "byteToString static \"\"");
+        assertNull(base64.encodeToString(b3),
+                "byteToString null");
+        assertNull(Base64.encodeBase64String(b3),
+                "byteToString static null");
+        assertEquals("K/fMJwH+Q5e0nr7tWsxwkA==", base64.encodeToString(b4),
+                "byteToString UUID");
+        assertEquals("K/fMJwH+Q5e0nr7tWsxwkA==", Base64.encodeBase64String(b4),
+                "byteToString static UUID");
+        assertEquals("K_fMJwH-Q5e0nr7tWsxwkA", Base64.encodeBase64URLSafeString(b4),
+                "byteToString static-url-safe UUID");
     }
 
     @Test
@@ -1285,18 +1265,16 @@ public class Base64Test {
                                                                                             // url-safe
                                                                                             // tests
 
-        assertEquals("StringToByte Hello World", "Hello World", StringUtils.newStringUtf8(base64.decode(s1)));
-        assertEquals("StringToByte Hello World", "Hello World",
-                StringUtils.newStringUtf8((byte[]) base64.decode((Object) s1)));
-        assertEquals("StringToByte static Hello World", "Hello World",
-                StringUtils.newStringUtf8(Base64.decodeBase64(s1)));
-        assertEquals("StringToByte \"\"", "", StringUtils.newStringUtf8(base64.decode(s2)));
-        assertEquals("StringToByte static \"\"", "", StringUtils.newStringUtf8(Base64.decodeBase64(s2)));
-        assertEquals("StringToByte null", null, StringUtils.newStringUtf8(base64.decode(s3)));
-        assertEquals("StringToByte static null", null, StringUtils.newStringUtf8(Base64.decodeBase64(s3)));
-        assertTrue("StringToByte UUID", Arrays.equals(b4, base64.decode(s4b)));
-        assertTrue("StringToByte static UUID", Arrays.equals(b4, Base64.decodeBase64(s4a)));
-        assertTrue("StringToByte static-url-safe UUID", Arrays.equals(b4, Base64.decodeBase64(s4b)));
+        assertEquals("Hello World", StringUtils.newStringUtf8(base64.decode(s1)), "StringToByte Hello World");
+        assertEquals("Hello World", StringUtils.newStringUtf8((byte[]) base64.decode((Object) s1)), "StringToByte Hello World");
+        assertEquals("Hello World", StringUtils.newStringUtf8(Base64.decodeBase64(s1)), "StringToByte static Hello World");
+        assertEquals("", StringUtils.newStringUtf8(base64.decode(s2)), "StringToByte \"\"");
+        assertEquals("", StringUtils.newStringUtf8(Base64.decodeBase64(s2)), "StringToByte static \"\"");
+        assertNull(StringUtils.newStringUtf8(base64.decode(s3)), "StringToByte null");
+        assertNull(StringUtils.newStringUtf8(Base64.decodeBase64(s3)), "StringToByte static null");
+        assertArrayEquals(b4, base64.decode(s4b), "StringToByte UUID");
+        assertArrayEquals(b4, Base64.decodeBase64(s4a), "StringToByte static UUID");
+        assertArrayEquals(b4, Base64.decodeBase64(s4b), "StringToByte static-url-safe UUID");
     }
 
     private String toString(final byte[] data) {
@@ -1323,19 +1301,14 @@ public class Base64Test {
         final Base64 b64 = new Base64(Base64_BYTES_PER_ENCODED_BLOCK, baLineSeparator);
         final String strOriginal = "Hello World";
         final String strDecoded = new String(b64.decode(b64.encode(StringUtils.getBytesUtf8(strOriginal))));
-        assertEquals("testDEFAULT_BUFFER_SIZE", strOriginal, strDecoded);
+        assertEquals(strOriginal, strDecoded, "testDEFAULT_BUFFER_SIZE");
     }
 
     @Test
     public void testBase64ImpossibleSamples() {
         final Base64 codec = new Base64(0, null, false, CodecPolicy.STRICT);
         for (final String s : BASE64_IMPOSSIBLE_CASES) {
-            try {
-                codec.decode(s);
-                fail();
-            } catch (final IllegalArgumentException ex) {
-                // expected
-            }
+            assertThrows(IllegalArgumentException.class, () -> codec.decode(s));
         }
     }
 
@@ -1390,12 +1363,8 @@ public class Base64Test {
             // If the lower bits are set we expect an exception. This is not a valid
             // final character.
             if (invalid || (i & emptyBitsMask) != 0) {
-                try {
-                    codec.decode(encoded);
-                    fail("Final base-64 digit should not be allowed");
-                } catch (final IllegalArgumentException ex) {
-                    // expected
-                }
+                assertThrows(IllegalArgumentException.class, () -> codec.decode(encoded),
+                        "Final base-64 digit should not be allowed");
                 // The default lenient mode should decode this
                 final byte[] decoded = defaultCodec.decode(encoded);
                 // Re-encoding should not match the original array as it was invalid
@@ -1405,7 +1374,7 @@ public class Base64Test {
                 final byte[] decoded = codec.decode(encoded);
                 // Compute the bits that were encoded. This should match the final decoded byte.
                 final int bitsEncoded = i >> discard;
-                assertEquals("Invalid decoding of last character", bitsEncoded, decoded[decoded.length - 1]);
+                assertEquals(bitsEncoded, decoded[decoded.length - 1], "Invalid decoding of last character");
                 // Re-encoding should match the original array (requires the same padding character)
                 assertArrayEquals(encoded, codec.encode(decoded));
             }
@@ -1437,9 +1406,10 @@ public class Base64Test {
         // 1GiB: Existing working buffer (due to doubling of default buffer size of 8192)
         // ~2GiB: New working buffer to allocate (due to doubling)
         // ~1.33GiB: Expected output size (since the working buffer is copied at the end)
-        // 32KiB: Some head room
+        // 32KiB: Some headroom
         final long estimatedMemory = (long) size1GiB * 4 + expectedLength + 32 * 1024;
-        Assume.assumeTrue("Not enough free memory for the test", presumableFreeMemory > estimatedMemory);
+        Assumptions.assumeTrue(presumableFreeMemory > estimatedMemory,
+                "Not enough free memory for the test");
 
         final byte[] bytes = new byte[size1GiB];
         final byte[] encoded = Base64.encodeBase64(bytes);
