@@ -17,11 +17,11 @@
 
 package org.apache.commons.codec.binary;
 
-import static org.junit.Assert.assertArrayEquals;
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertTrue;
-import static org.junit.Assert.fail;
+import static org.junit.jupiter.api.Assertions.assertArrayEquals;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertNotEquals;
+import static org.junit.jupiter.api.Assertions.assertThrows;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 
 import java.io.UnsupportedEncodingException;
 import java.nio.ByteBuffer;
@@ -29,16 +29,14 @@ import java.nio.charset.Charset;
 import java.nio.charset.StandardCharsets;
 import java.nio.charset.UnsupportedCharsetException;
 import java.util.Arrays;
-import java.util.Random;
 import java.util.concurrent.ThreadLocalRandom;
+
 import org.apache.commons.codec.DecoderException;
 import org.apache.commons.codec.EncoderException;
-import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
 /**
  * Tests {@link org.apache.commons.codec.binary.Hex}.
- *
  */
 public class HexTest {
 
@@ -82,7 +80,7 @@ public class HexTest {
             final byte[] bytes = source.getBytes(name);
             final String str = new String(bytes, name);
             final boolean equals = source.equals(str);
-            if (equals == false) {
+            if (!equals) {
                 // Here with:
                 //
                 // Java Sun 1.4.2_19 x86 32-bits on Windows XP
@@ -106,14 +104,7 @@ public class HexTest {
                 log("FAILED charsetSanityCheck=Interesting Java charset oddity: Roundtrip failed for " + name);
             }
             return equals;
-        } catch (final UnsupportedEncodingException e) {
-            // Should NEVER happen since we are getting the name from the Charset class.
-            if (LOG) {
-                log("FAILED charsetSanityCheck=" + name + ", e=" + e);
-                log(e);
-            }
-            return false;
-        } catch (final UnsupportedOperationException e) {
+        } catch (final UnsupportedEncodingException | UnsupportedOperationException e) {
             // Caught here with:
             // x-JISAutoDetect on Windows XP and Java Sun 1.4.2_19 x86 32-bits
             // x-JISAutoDetect on Windows XP and Java Sun 1.5.0_17 x86 32-bits
@@ -127,30 +118,15 @@ public class HexTest {
     }
 
     private void checkDecodeHexCharArrayOddCharacters(final char[] data) {
-        try {
-            Hex.decodeHex(data);
-            fail("An exception wasn't thrown when trying to decode an odd number of characters");
-        } catch (final DecoderException e) {
-            // Expected exception
-        }
+        assertThrows(DecoderException.class, () -> Hex.decodeHex(data));
     }
 
     private void checkDecodeHexByteBufferOddCharacters(final ByteBuffer data) {
-        try {
-            new Hex().decode(data);
-            fail("An exception wasn't thrown when trying to decode an odd number of characters");
-        } catch (final DecoderException e) {
-            // Expected exception
-        }
+        assertThrows(DecoderException.class, () -> new Hex().decode(data));
     }
 
     private void checkDecodeHexCharArrayOddCharacters(final String data) {
-        try {
-            Hex.decodeHex(data);
-            fail("An exception wasn't thrown when trying to decode an odd number of characters");
-        } catch (final DecoderException e) {
-            // Expected exception
-        }
+        assertThrows(DecoderException.class, () -> Hex.decodeHex(data));
     }
 
     private void log(final String s) {
@@ -182,7 +158,7 @@ public class HexTest {
      */
     private void testCustomCharset(final String name, final String parent) throws UnsupportedEncodingException,
             DecoderException {
-        if (charsetSanityCheck(name) == false) {
+        if (!charsetSanityCheck(name)) {
             return;
         }
         log(parent + "=" + name);
@@ -197,27 +173,26 @@ public class HexTest {
         String expectedHexString = Hex.encodeHexString(sourceBytes);
         // ... and get the bytes in the expected charset
         final byte[] expectedHexStringBytes = expectedHexString.getBytes(name);
-        Assert.assertTrue(Arrays.equals(expectedHexStringBytes, actualEncodedBytes));
+        assertArrayEquals(expectedHexStringBytes, actualEncodedBytes);
         // test 2
         String actualStringFromBytes = new String(actualEncodedBytes, name);
-        assertEquals(name + ", expectedHexString=" + expectedHexString + ", actualStringFromBytes=" +
-                actualStringFromBytes, expectedHexString, actualStringFromBytes);
+        assertEquals(expectedHexString, actualStringFromBytes, name);
         // second test:
         final Hex utf8Codec = new Hex();
         expectedHexString = "48656c6c6f20576f726c64";
         final byte[] decodedUtf8Bytes = (byte[]) utf8Codec.decode(expectedHexString);
         actualStringFromBytes = new String(decodedUtf8Bytes, utf8Codec.getCharset());
         // sanity check:
-        assertEquals(name, sourceString, actualStringFromBytes);
+        assertEquals(sourceString, actualStringFromBytes, name);
         // actual check:
         final byte[] decodedCustomBytes = customCodec.decode(actualEncodedBytes);
         actualStringFromBytes = new String(decodedCustomBytes, name);
-        assertEquals(name, sourceString, actualStringFromBytes);
+        assertEquals(sourceString, actualStringFromBytes, name);
     }
 
-    @Test(expected = UnsupportedCharsetException.class)
+    @Test
     public void testCustomCharsetBadName() {
-        new Hex(BAD_ENCODING_NAME);
+        assertThrows(UnsupportedCharsetException.class, () -> new Hex(BAD_ENCODING_NAME));
     }
 
     @Test
@@ -227,47 +202,32 @@ public class HexTest {
 
     @Test
     public void testDecodeBadCharacterPos0() {
-        try {
-            new Hex().decode("q0");
-            fail("An exception wasn't thrown when trying to decode an illegal character");
-        } catch (final DecoderException e) {
-            // Expected exception
-        }
+        assertThrows(DecoderException.class, () -> new Hex().decode("q0"));
     }
 
     @Test
     public void testDecodeBadCharacterPos1() {
-        try {
-            new Hex().decode("0q");
-            fail("An exception wasn't thrown when trying to decode an illegal character");
-        } catch (final DecoderException e) {
-            // Expected exception
-        }
+        assertThrows(DecoderException.class, () -> new Hex().decode("0q"));
     }
 
     @Test
     public void testDecodeByteArrayEmpty() throws DecoderException {
-        assertTrue(Arrays.equals(new byte[0], new Hex().decode(new byte[0])));
+        assertArrayEquals(new byte[0], new Hex().decode(new byte[0]));
     }
 
     @Test
     public void testDecodeByteArrayObjectEmpty() throws DecoderException {
-        assertTrue(Arrays.equals(new byte[0], (byte[]) new Hex().decode((Object) new byte[0])));
+        assertArrayEquals(new byte[0], (byte[]) new Hex().decode((Object) new byte[0]));
     }
 
     @Test
     public void testDecodeByteArrayOddCharacters() {
-        try {
-            new Hex().decode(new byte[] { 65 });
-            fail("An exception wasn't thrown when trying to decode an odd number of characters");
-        } catch (final DecoderException e) {
-            // Expected exception
-        }
+        assertThrows(DecoderException.class, () -> new Hex().decode(new byte[] { 65 }), "odd number of characters");
     }
 
     @Test
     public void testDecodeByteBufferEmpty() throws DecoderException {
-        assertTrue(Arrays.equals(new byte[0], new Hex().decode(allocate(0))));
+        assertArrayEquals(new byte[0], new Hex().decode(allocate(0)));
     }
 
     @Test
@@ -275,13 +235,13 @@ public class HexTest {
         final ByteBuffer bb = allocate(10);
         // Effectively set remaining == 0 => empty
         bb.flip();
-        assertTrue(Arrays.equals(new byte[0], new Hex().decode(bb)));
+        assertArrayEquals(new byte[0], new Hex().decode(bb));
         assertEquals(0, bb.remaining());
     }
 
     @Test
     public void testDecodeByteBufferObjectEmpty() throws DecoderException {
-        assertTrue(Arrays.equals(new byte[0], (byte[]) new Hex().decode((Object) allocate(0))));
+        assertArrayEquals(new byte[0], (byte[]) new Hex().decode((Object) allocate(0)));
     }
 
     @Test
@@ -303,22 +263,17 @@ public class HexTest {
 
     @Test
     public void testDecodeHexCharArrayEmpty() throws DecoderException {
-        assertTrue(Arrays.equals(new byte[0], Hex.decodeHex(new char[0])));
+        assertArrayEquals(new byte[0], Hex.decodeHex(new char[0]));
     }
 
     @Test
     public void testDecodeHexStringEmpty() throws DecoderException {
-        assertTrue(Arrays.equals(new byte[0], Hex.decodeHex("")));
+        assertArrayEquals(new byte[0], Hex.decodeHex(""));
     }
 
     @Test
     public void testDecodeClassCastException() {
-        try {
-            new Hex().decode(new int[] { 65 });
-            fail("An exception wasn't thrown when trying to decode.");
-        } catch (final DecoderException e) {
-            // Expected exception
-        }
+        assertThrows(DecoderException.class, () -> new Hex().decode(new int[] { 65 }), "odd number of characters");
     }
 
     @Test
@@ -341,31 +296,28 @@ public class HexTest {
         checkDecodeHexCharArrayOddCharacters(new char[] { 'A', 'B', 'C', 'D', 'E' });
     }
 
-    @Test(expected = DecoderException.class)
-    public void testDecodeHexCharArrayOutBufferUnderSized() throws DecoderException {
+    @Test
+    public void testDecodeHexCharArrayOutBufferUnderSized() {
         final byte[] out = new byte[4];
-        Hex.decodeHex("aabbccddeeff".toCharArray(), out, 0);
+        assertThrows(DecoderException.class, () -> Hex.decodeHex("aabbccddeeff".toCharArray(), out, 0));
     }
 
-    @Test(expected = DecoderException.class)
-    public void testDecodeHexCharArrayOutBufferUnderSizedByOffset() throws DecoderException {
+    @Test
+    public void testDecodeHexCharArrayOutBufferUnderSizedByOffset() {
         final byte[] out = new byte[6];
-        Hex.decodeHex("aabbccddeeff".toCharArray(), out, 1);
+        assertThrows(DecoderException.class, () -> Hex.decodeHex("aabbccddeeff".toCharArray(), out, 1));
+
     }
 
     @Test
     public void testDecodeHexStringOddCharacters() {
-        try {
-            new Hex().decode("6");
-            fail("An exception wasn't thrown when trying to decode an odd number of characters");
-        } catch (final DecoderException e) {
-            // Expected exception
-        }
+        assertThrows(DecoderException.class, () -> new Hex().decode("6"), "odd number of characters");
+
     }
 
     @Test
     public void testDecodeStringEmpty() throws DecoderException {
-        assertTrue(Arrays.equals(new byte[0], (byte[]) new Hex().decode("")));
+        assertArrayEquals(new byte[0], (byte[]) new Hex().decode(""));
     }
 
     @Test
@@ -383,17 +335,17 @@ public class HexTest {
 
     @Test
     public void testEncodeByteArrayEmpty() {
-        assertTrue(Arrays.equals(new byte[0], new Hex().encode(new byte[0])));
+        assertArrayEquals(new byte[0], new Hex().encode(new byte[0]));
     }
 
     @Test
     public void testEncodeByteArrayObjectEmpty() throws EncoderException {
-        assertTrue(Arrays.equals(new char[0], (char[]) new Hex().encode((Object) new byte[0])));
+        assertArrayEquals(new char[0], (char[]) new Hex().encode((Object) new byte[0]));
     }
 
     @Test
     public void testEncodeByteBufferEmpty() {
-        assertTrue(Arrays.equals(new byte[0], new Hex().encode(allocate(0))));
+        assertArrayEquals(new byte[0], new Hex().encode(allocate(0)));
     }
 
     @Test
@@ -401,23 +353,18 @@ public class HexTest {
         final ByteBuffer bb = allocate(10);
         // Effectively set remaining == 0 => empty
         bb.flip();
-        assertTrue(Arrays.equals(new byte[0], new Hex().encode(bb)));
+        assertArrayEquals(new byte[0], new Hex().encode(bb));
         assertEquals(0, bb.remaining());
     }
 
     @Test
     public void testEncodeByteBufferObjectEmpty() throws EncoderException {
-        assertTrue(Arrays.equals(new char[0], (char[]) new Hex().encode((Object) allocate(0))));
+        assertArrayEquals(new char[0], (char[]) new Hex().encode((Object) allocate(0)));
     }
 
     @Test
     public void testEncodeClassCastException() {
-        try {
-            new Hex().encode(new int[] { 65 });
-            fail("An exception wasn't thrown when trying to encode.");
-        } catch (final EncoderException e) {
-            // Expected exception
-        }
+        assertThrows(EncoderException.class, () -> new Hex().encode(new int[] { 65 }));
     }
 
     @Test
@@ -431,29 +378,29 @@ public class HexTest {
             // static API
             final char[] encodedChars = Hex.encodeHex(data);
             byte[] decodedBytes = Hex.decodeHex(encodedChars);
-            assertTrue(Arrays.equals(data, decodedBytes));
+            assertArrayEquals(data, decodedBytes);
 
             // instance API with array parameter
             final byte[] encodedStringBytes = hex.encode(data);
             decodedBytes = hex.decode(encodedStringBytes);
-            assertTrue(Arrays.equals(data, decodedBytes));
+            assertArrayEquals(data, decodedBytes);
 
             // instance API with char[] (Object) parameter
             String dataString = new String(encodedChars);
             char[] encodedStringChars = (char[]) hex.encode(dataString);
             decodedBytes = (byte[]) hex.decode(encodedStringChars);
-            assertTrue(Arrays.equals(StringUtils.getBytesUtf8(dataString), decodedBytes));
+            assertArrayEquals(StringUtils.getBytesUtf8(dataString), decodedBytes);
 
             // instance API with String (Object) parameter
             dataString = new String(encodedChars);
             encodedStringChars = (char[]) hex.encode(dataString);
             decodedBytes = (byte[]) hex.decode(new String(encodedStringChars));
-            assertTrue(Arrays.equals(StringUtils.getBytesUtf8(dataString), decodedBytes));
+            assertArrayEquals(StringUtils.getBytesUtf8(dataString), decodedBytes);
         }
     }
 
     @Test
-    public void testEncodeDecodeHexCharArrayRandomToOutput() throws DecoderException, EncoderException {
+    public void testEncodeDecodeHexCharArrayRandomToOutput() throws DecoderException {
         for (int i = 5; i > 0; i--) {
             final byte[] data = new byte[ThreadLocalRandom.current().nextInt(10000) + 1];
             ThreadLocalRandom.current().nextBytes(data);
@@ -474,8 +421,8 @@ public class HexTest {
 
     @Test
     public void testEncodeHexByteArrayEmpty() {
-        assertTrue(Arrays.equals(new char[0], Hex.encodeHex(new byte[0])));
-        assertTrue(Arrays.equals(new byte[0], new Hex().encode(new byte[0])));
+        assertArrayEquals(new char[0], Hex.encodeHex(new byte[0]));
+        assertArrayEquals(new byte[0], new Hex().encode(new byte[0]));
     }
 
     @Test
@@ -488,7 +435,7 @@ public class HexTest {
         actual = Hex.encodeHex(b, true);
         assertEquals(expected, new String(actual));
         actual = Hex.encodeHex(b, false);
-        assertFalse(expected.equals(new String(actual)));
+        assertNotEquals(expected, new String(actual));
     }
 
     @Test
@@ -497,11 +444,11 @@ public class HexTest {
         final String expected = "48656C6C6F20576F726C64";
         char[] actual;
         actual = Hex.encodeHex(b);
-        assertFalse(expected.equals(new String(actual)));
+        assertNotEquals(expected, new String(actual));
         actual = Hex.encodeHex(b, true);
-        assertFalse(expected.equals(new String(actual)));
+        assertNotEquals(expected, new String(actual));
         actual = Hex.encodeHex(b, false);
-        assertTrue(expected.equals(new String(actual)));
+        assertEquals(expected, new String(actual));
     }
 
     @Test
@@ -512,8 +459,8 @@ public class HexTest {
 
     @Test
     public void testEncodeHexByteBufferEmpty() {
-        assertTrue(Arrays.equals(new char[0], Hex.encodeHex(allocate(0))));
-        assertTrue(Arrays.equals(new byte[0], new Hex().encode(allocate(0))));
+        assertArrayEquals(new char[0], Hex.encodeHex(allocate(0)));
+        assertArrayEquals(new byte[0], new Hex().encode(allocate(0)));
     }
 
     @Test
@@ -607,20 +554,18 @@ public class HexTest {
         assertArrayEquals("64".toCharArray(), hex);
     }
 
-    @Test(expected=ArrayIndexOutOfBoundsException.class)
+    @Test
     public void testEncodeHexPartialInputUnderbounds() {
         final byte data[] = "hello world".getBytes(StandardCharsets.UTF_8);
 
-        final char[] hex = Hex.encodeHex(data, -2, 10, true);
-        assertArrayEquals("64".toCharArray(), hex);
+        assertThrows(ArrayIndexOutOfBoundsException.class, () -> Hex.encodeHex(data, -2, 10, true));
     }
 
-    @Test(expected=ArrayIndexOutOfBoundsException.class)
+    @Test
     public void testEncodeHexPartialInputOverbounds() {
         final byte data[] = "hello world".getBytes(StandardCharsets.UTF_8);
 
-        final char[] hex = Hex.encodeHex(data, 9, 10, true);
-        assertArrayEquals("64".toCharArray(), hex);
+        assertThrows(ArrayIndexOutOfBoundsException.class, () -> Hex.encodeHex(data, 9, 10, true));
     }
 
     @Test
@@ -705,17 +650,17 @@ public class HexTest {
 
     @Test
     public void testEncodeStringEmpty() throws EncoderException {
-        assertTrue(Arrays.equals(new char[0], (char[]) new Hex().encode("")));
+        assertArrayEquals(new char[0], (char[]) new Hex().encode(""));
     }
 
     @Test
     public void testGetCharset() {
-        Assert.assertEquals(StandardCharsets.UTF_8, new Hex(StandardCharsets.UTF_8).getCharset());
+        assertEquals(StandardCharsets.UTF_8, new Hex(StandardCharsets.UTF_8).getCharset());
     }
 
     @Test
     public void testGetCharsetName() {
-        Assert.assertEquals(StandardCharsets.UTF_8.name(), new Hex(StandardCharsets.UTF_8).getCharsetName());
+        assertEquals(StandardCharsets.UTF_8.name(), new Hex(StandardCharsets.UTF_8).getCharsetName());
     }
 
     @Test
