@@ -18,17 +18,19 @@
 package org.apache.commons.codec.digest;
 
 import static org.apache.commons.codec.binary.StringUtils.getBytesUtf8;
-import static org.junit.Assert.assertArrayEquals;
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertTrue;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertArrayEquals;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertThrows;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+import static org.junit.jupiter.api.Assumptions.assumeTrue;
 
 import java.io.ByteArrayInputStream;
 import java.io.File;
 import java.io.FileInputStream;
-import java.io.FileOutputStream;
 import java.io.IOException;
+import java.io.OutputStream;
 import java.io.RandomAccessFile;
 import java.nio.ByteBuffer;
 import java.nio.file.Files;
@@ -42,14 +44,12 @@ import org.apache.commons.codec.binary.Hex;
 import org.apache.commons.codec.binary.StringUtils;
 import org.apache.commons.lang3.JavaVersion;
 import org.apache.commons.lang3.SystemUtils;
-import org.junit.After;
-import org.junit.Assume;
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
 /**
  * Tests DigestUtils methods.
- *
  */
 public class DigestUtilsTest {
 
@@ -57,60 +57,54 @@ public class DigestUtilsTest {
 
     private final byte[] testData = new byte[1024 * 1024];
 
-    private File testFile;
+    private Path testFile;
 
-    private File testRandomAccessFile;
+    private Path testRandomAccessFile;
 
     private RandomAccessFile testRandomAccessFileWrapper;
 
     private void assumeJava8() {
-        Assume.assumeTrue(SystemUtils.isJavaVersionAtLeast(JavaVersion.JAVA_1_8));
+        assumeTrue(SystemUtils.isJavaVersionAtLeast(JavaVersion.JAVA_1_8));
     }
 
     private void assumeJava9() {
-        Assume.assumeTrue(SystemUtils.isJavaVersionAtLeast(JavaVersion.JAVA_9));
+        assumeTrue(SystemUtils.isJavaVersionAtLeast(JavaVersion.JAVA_9));
     }
 
     byte[] getTestData() {
         return testData;
     }
 
-    File getTestFile() {
-        return testFile;
-    }
-
     Path getTestPath() {
-        return testFile.toPath();
+        return testFile;
     }
 
     RandomAccessFile getTestRandomAccessFile() {
         return testRandomAccessFileWrapper;
     }
 
-    @Before
+    @BeforeEach
     public void setUp() throws Exception {
         new Random().nextBytes(testData);
-        testFile = File.createTempFile(DigestUtilsTest.class.getName(), ".dat");
-        try (final FileOutputStream fos = new FileOutputStream(testFile)) {
+        testFile = Files.createTempFile(DigestUtilsTest.class.getName(), ".dat");
+        try (final OutputStream fos = Files.newOutputStream(testFile)) {
             fos.write(testData);
         }
 
-        testRandomAccessFile = File.createTempFile(DigestUtilsTest.class.getName(), ".dat");
-        try (final FileOutputStream fos = new FileOutputStream(testRandomAccessFile)) {
+        testRandomAccessFile = Files.createTempFile(DigestUtilsTest.class.getName(), ".dat");
+        try (final OutputStream fos = Files.newOutputStream(testRandomAccessFile)) {
             fos.write(testData);
         }
-        testRandomAccessFileWrapper = new RandomAccessFile(testRandomAccessFile, "rw");
+        testRandomAccessFileWrapper = new RandomAccessFile(testRandomAccessFile.toFile(), "rw");
     }
 
-    @After
-    public void tearDown() {
-        if (!testFile.delete()) {
-            testFile.deleteOnExit();
-        }
-
-        if (!testRandomAccessFile.delete()) {
-            testRandomAccessFile.deleteOnExit();
+    @AfterEach
+    public void tearDown() throws IOException {
+        if (testRandomAccessFileWrapper != null) {
+            testRandomAccessFileWrapper.close();
         }
+        Files.deleteIfExists(testFile);
+        Files.deleteIfExists(testRandomAccessFile);
     }
 
     @Test
@@ -134,9 +128,9 @@ public class DigestUtilsTest {
         assertEquals(MessageDigestAlgorithms.MD5, digestUtils.getMessageDigest().getAlgorithm());
     }
 
-    @Test(expected=IllegalArgumentException.class)
+    @Test
     public void testInternalNoSuchAlgorithmException() {
-        DigestUtils.getDigest("Bogus Bogus");
+        assertThrows(IllegalArgumentException.class, () -> DigestUtils.getDigest("Bogus Bogus"));
     }
 
     @Test
