@@ -17,14 +17,15 @@
 
 package org.apache.commons.codec.language;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertTrue;
-import static org.junit.Assert.fail;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertNull;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+import static org.junit.jupiter.api.Assertions.fail;
 
 import org.apache.commons.codec.EncoderException;
 import org.apache.commons.codec.StringEncoderAbstractTest;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
 /**
  * Tests {@link DoubleMetaphone}.
@@ -1011,7 +1012,7 @@ public class DoubleMetaphoneTest extends StringEncoderAbstractTest<DoubleMetapho
         try {
             assertEquals(expected, this.getStringEncoder().encode((Object) source));
         } catch (final EncoderException e) {
-            fail("Unexpected expection: " + e);
+            fail("Unexpected exception: " + e);
         }
         assertEquals(expected, this.getStringEncoder().doubleMetaphone(source));
         assertEquals(expected, this.getStringEncoder().doubleMetaphone(source, false));
@@ -1035,11 +1036,11 @@ public class DoubleMetaphoneTest extends StringEncoderAbstractTest<DoubleMetapho
             final String name0 = pair[0];
             final String name1 = pair[1];
             final String failMsg = "Expected match between " + name0 + " and " + name1 + " (use alternate: " + useAlternate + ")";
-            assertTrue(failMsg, this.getStringEncoder().isDoubleMetaphoneEqual(name0, name1, useAlternate));
-            assertTrue(failMsg, this.getStringEncoder().isDoubleMetaphoneEqual(name1, name0, useAlternate));
+            assertTrue(this.getStringEncoder().isDoubleMetaphoneEqual(name0, name1, useAlternate), failMsg);
+            assertTrue(this.getStringEncoder().isDoubleMetaphoneEqual(name1, name0, useAlternate), failMsg);
             if (!useAlternate) {
-                assertTrue(failMsg, this.getStringEncoder().isDoubleMetaphoneEqual(name0, name1));
-                assertTrue(failMsg, this.getStringEncoder().isDoubleMetaphoneEqual(name1, name0));
+                assertTrue(this.getStringEncoder().isDoubleMetaphoneEqual(name0, name1), failMsg);
+                assertTrue(this.getStringEncoder().isDoubleMetaphoneEqual(name1, name0), failMsg);
             }
         }
     }
@@ -1112,15 +1113,15 @@ public class DoubleMetaphoneTest extends StringEncoderAbstractTest<DoubleMetapho
 
     @Test
     public void testEmpty() {
-        assertEquals(null, this.getStringEncoder().doubleMetaphone(null));
-        assertEquals(null, this.getStringEncoder().doubleMetaphone(""));
-        assertEquals(null, this.getStringEncoder().doubleMetaphone(" "));
-        assertEquals(null, this.getStringEncoder().doubleMetaphone("\t\n\r "));
+        assertNull(this.getStringEncoder().doubleMetaphone(null));
+        assertNull(this.getStringEncoder().doubleMetaphone(""));
+        assertNull(this.getStringEncoder().doubleMetaphone(" "));
+        assertNull(this.getStringEncoder().doubleMetaphone("\t\n\r "));
     }
 
     @Test
     public void testIsDoubleMetaphoneEqualBasic() {
-        final String[][] testFixture = new String[][] { {
+        final String[][] testFixture = { {
                 "", "" }, {
                 "Case", "case" }, {
                 "CASE", "Case" }, {
@@ -1149,7 +1150,7 @@ public class DoubleMetaphoneTest extends StringEncoderAbstractTest<DoubleMetapho
 
     @Test
     public void testIsDoubleMetaphoneEqualExtended2() {
-        final String[][] testFixture = new String[][] { { "Jablonski", "Yablonsky" }
+        final String[][] testFixture = { { "Jablonski", "Yablonsky" }
         };
         //doubleMetaphoneEqualTest(testFixture, false);
         doubleMetaphoneEqualTest(testFixture, true);
@@ -1172,7 +1173,7 @@ public class DoubleMetaphoneTest extends StringEncoderAbstractTest<DoubleMetapho
             final String name1 = FIXTURE[i][1];
             final boolean match1 = this.getStringEncoder().isDoubleMetaphoneEqual(name0, name1, false);
             final boolean match2 = this.getStringEncoder().isDoubleMetaphoneEqual(name0, name1, true);
-            if (match1 == false && match2 == false) {
+            if (!match1 && !match2) {
                 final String failMsg = "[" + i + "] " + name0 + " and " + name1 + cr;
                 failures.append(failMsg);
                 failCount++;
@@ -1199,7 +1200,7 @@ public class DoubleMetaphoneTest extends StringEncoderAbstractTest<DoubleMetapho
             final String name1 = MATCHES[i][1];
             final boolean match1 = this.getStringEncoder().isDoubleMetaphoneEqual(name0, name1, false);
             final boolean match2 = this.getStringEncoder().isDoubleMetaphoneEqual(name0, name1, true);
-            if (match1 == false && match2 == false) {
+            if (!match1 && !match2) {
                 fail("Expected match [" + i + "] " + name0 + " and " + name1);
             }
         }
@@ -1226,15 +1227,15 @@ public class DoubleMetaphoneTest extends StringEncoderAbstractTest<DoubleMetapho
         final DoubleMetaphone doubleMetaphone = new DoubleMetaphone();
 
         // Sanity check of default settings
-        assertEquals("Default Max Code Length", 4, doubleMetaphone.getMaxCodeLen());
-        assertEquals("Default Primary",   "JMPT", doubleMetaphone.doubleMetaphone(value, false));
-        assertEquals("Default Alternate", "AMPT", doubleMetaphone.doubleMetaphone(value, true));
+        assertEquals(4, doubleMetaphone.getMaxCodeLen(), "Default Max Code Length");
+        assertEquals(  "JMPT", doubleMetaphone.doubleMetaphone(value, false), "Default Primary");
+        assertEquals("AMPT", doubleMetaphone.doubleMetaphone(value, true), "Default Alternate");
 
         // Check setting Max Code Length
         doubleMetaphone.setMaxCodeLen(3);
-        assertEquals("Set Max Code Length", 3, doubleMetaphone.getMaxCodeLen());
-        assertEquals("Max=3 Primary",   "JMP", doubleMetaphone.doubleMetaphone(value, false));
-        assertEquals("Max=3 Alternate", "AMP", doubleMetaphone.doubleMetaphone(value, true));
+        assertEquals(3, doubleMetaphone.getMaxCodeLen(), "Set Max Code Length");
+        assertEquals(  "JMP", doubleMetaphone.doubleMetaphone(value, false), "Max=3 Primary");
+        assertEquals("AMP", doubleMetaphone.doubleMetaphone(value, true), "Max=3 Alternate");
     }
 
     public void validateFixture(final String[][] pairs) {
